@@ -1,15 +1,29 @@
 #!/usr/bin/env python
 """
 SetupHelper -- helper module to automate setup boilerplate
-Copyright (C) 2008 by Peter A. Donis
+Copyright (C) 2008-2009 by Peter A. Donis
 
 Released under the Python Software Foundation License.
 
 This setup helper module automates much of the boilerplate.
 The entry point is the setup_main function, which expects to be
 called with a dictionary mapping variable names to values; the
-variable names supported are as follows (most of them map in
-the obvious way to setup keyword arguments):
+supported variable names are listed below.
+
+The recommended way to call setup_main is to first define all the
+necessary variables as module globals in your setup.py file, and
+then simply do:
+
+    from SetupHelper import setup_main
+    setup_main(globals())
+
+This will pass your module globals to SetupHelper, which will then
+do all the grunt work! (SetupHelper automatically filters out globals
+like __name__, __file__, and so on that are supplied by Python, so they
+won't interfere with yours.)
+
+The variable names supported are as follows (most of them map in a
+fairly obvious way to setup keyword arguments):
 
 __progname__           -- name of the program
 __version__            -- program version (TODO: add __dev_build__)
@@ -29,15 +43,18 @@ __long_description__   -- triple-quoted string containing long
 __start_line__         -- contents of the line in README where the
                           long description should start (i.e.,
                           this line and all after it until the
-                          end line will be included)
+                          end line will be included), or the line
+                          number where it should start
 __end_line__           -- contents of the line in README where the
                           long description should end (i.e., this
                           line and all after it will *not* be
-                          included)
+                          included), or the line number where it
+                          should end (negative numbers count from
+                          the end of the file)
 
 __author__             -- author name
 __author_email__       -- author e-mail address
-__url__                -- home URL for the author or progra
+__url__                -- home URL for the author or program
 
 __download_url__       -- URL for downloading the program; should
                           not be needed, use __url_base__ and
@@ -48,11 +65,12 @@ __url_base__           -- base URL for download; assumes that the
                           omitted, the PyPI base URL will be used
 __url_ext__            -- extension for the download file; can be
                           ('tar.gz', 'zip', 'exe', 'dmg'); defaults
-                          to 'tar.gz'
+                          to 'tar.gz' if this and the next variable
+                          are both omitted
 __url_type__           -- type of file being downloaded; can be
                           a valid __url_ext__ value or a valid
-                          value for os.name ('posix', 'nt', and
-                          'mac' are currently supported); if omitted,
+                          value for os.name ('posix' and 'nt'
+                          are currently supported); if omitted,
                           __url_ext__ (or its default) is used
 
 __license__            -- the name of the distribution license (valid
@@ -140,8 +158,7 @@ __package_dirs__       -- list of subdirectories of the root of the
                           source tree that contain packages; if this is
                           omitted, any subdirectory that contains an
                           __init__.py file will be treated as a package
-                          (this default should generally be sufficient);
-                          note that the logic
+                          (this default should generally be sufficient)
 __package_data__       -- mapping of package names to lists of data
                           files; this should generally not be needed
                           as the default package finding algorithm
@@ -191,21 +208,10 @@ __post_install__       -- list of script names to be run after install
                           setup command is anything other than install);
                           each name must be a valid command at a shell prompt
 
-Note that this list of variables is for metadata version 1.0 (PEP 241);
-this module does not (yet) support the additional metadata defined in
-version 1.1 (PEP 314), except for the (very limited) support for the
-requires keyword (which is not included in the metadata that are
-registered with PyPI) unless you are using setuptools.
-
-The recommended way to call setup_main is to first define all the
-necessary variables as module globals in your setup.py file, and
-then simply do:
-
-    from SetupHelper import setup_main
-    setup_main(globals())
-
-This will pass your module globals to SetupHelper, which will then
-do all the grunt work!
+Note that this list of variables is for metadata version 1.1 (PEP 314);
+SetupHelper supports that version even if your version of Python does
+not (2.4 and earlier). Note that this applies whether or not you are
+using setuptools; setuptools uses the distutils metadata support.
 
 The setup_main function also allows you to override several of the
 defaults for the SetupHelper class; the currently accepted overrides
@@ -242,8 +248,9 @@ script's globals as described above.
 
 import sys
 import os
+from itertools import imap, izip
 
-SETUPHELPER_VERSION = (0, 3, 1)
+SETUPHELPER_VERSION = (0, 4, 4)
 
 def version_tuple(ver_s, dev=False):
     """
@@ -255,7 +262,7 @@ def version_tuple(ver_s, dev=False):
     
     ver_t = ver_s.split('.')
     try:
-        result = tuple(map(int, ver_t))
+        result = tuple(imap(int, ver_t))
         if dev:
             return (result, ())
         else:
@@ -289,8 +296,7 @@ def version_string(ver_t, dev_t=None):
     """
     
     try:
-        result = map(int, ver_t)
-        result = '.'.join(map(str, result))
+        result = '.'.join(imap(str, imap(int, ver_t)))
         if dev_t is not None:
             result += dev_string(dev_t)
     except ValueError:
@@ -437,13 +443,40 @@ if sys.version < '2.5':
     # Now monkeypatch distutils with our extended class
     distutils.dist.DistributionMetadata = DistributionMetadata
 
+# Mapping of platforms to allowed archive extensions
+
+archive_extensions = {
+    'darwin': [".dmg", ".tar.gz", ".tar", ".zip"],
+    'linux2': [".tar.gz", ".tar.bz2", ".zip", ".tar"],
+    'win32': [".exe", ".zip", ".tar.gz", ".tar"] }
+
+install_scripts_dir = None # see ugly hack below
+
 def distutils_default():
     """ Support function for Python-provided distutils. """
     
+    import distutils.command.install_scripts
+    from distutils.command.install_scripts import install_scripts as _install_scripts
     from distutils.core import setup, Extension
     import urllib2
     import re
     
+    class install_scripts(_install_scripts):
+        """
+        Captures the script installation directory so that post-install scripts
+        will be run correctly. Yes, this is an ugly hack; if distutils would
+        expose these directories to setup scripts all this would be unnecessary.
+        """
+        
+        def finalize_options(self):
+            global install_scripts_dir
+            _install_scripts.finalize_options(self)
+            install_scripts_dir = self.install_dir
+            print "Installing scripts to %s ..." % install_scripts_dir
+    
+    # Monkeypatch distutils with our hacked class above
+    distutils.command.install_scripts.install_scripts = install_scripts
+    
     class RequiresHelper(object):
         """
         Helper class to handle requires keyword. Should be
@@ -451,17 +484,11 @@ def distutils_default():
         # requires variable/keyword.
         """
         
+        # TODO: add a command line option to specify a different repository base URL
         pypi_url = "http://pypi.python.org/simple/"
         user_agent = "Python-urllib/%s SetupHelper/%s" % (
             urllib2.__version__, SETUPHELPER_VERSION)
         
-        def __init__(self, requires, opts, debug=False):
-            self._requires = requires
-            self._debug = debug
-            
-            self.setup_opts = opts
-            self.srcdir = ""
-        
         # NOTE: this is *not* fully general URL detection and parsing; it only
         # does the minimum necessary to work with HTML pages like those on PyPI
         # that contain properly formatted URLs within relatively "clean" content
@@ -491,15 +518,19 @@ def distutils_default():
                 self.__m = m
                 self.url = m.group()
                 self.scheme, self.hostname, self.domain, self.portspec, self.pathname, \
-                    self.params, self.query, self.fragment = m.groups()        
+                    self.params, self.query, self.fragment = m.groups()
         
         try:
-            allowed_extensions = {
-                'darwin': [".dmg", ".tar.gz", ".tar"],
-                'linux2': [".tar.gz", ".tar.bz2", ".zip", ".tar"],
-                'win32': [".exe", ".zip", ".tar.gz", ".tar"] }[sys.platform]
+            allowed_extensions = archive_extensions[sys.platform]
         except KeyError:
-            allowed_extensions = ["tar.gz", ".tar"] # reasonably safe choice
+            allowed_extensions = ["tar.gz", ".zip"] # reasonably safe choice
+        
+        def __init__(self, requires, opts, debug=False):
+            self._requires = requires
+            self._debug = debug
+            
+            self.setup_opts = opts
+            self.srcdir = ""
         
         def find_pattern(data, pattern, klass=None):
             r = re.compile(pattern)
@@ -526,7 +557,7 @@ def distutils_default():
         def version_tuple(verstr, length=4):
             """ Return tuple of version numbers, padded with -1 to length to make sorting easier. """
             t = verstr.split('.')
-            return tuple(map(int, t) + [-1]*(length - len(t)))
+            return tuple(imap(int, t) + [-1]*(length - len(t)))
         version_tuple = staticmethod(version_tuple)
         
         def find_archives_in_iterable(self, iterable, progname):
@@ -587,7 +618,7 @@ def distutils_default():
                 return versions[0]
             return None
         
-        def get_latest_version(self, data, progname, hrefs=False):
+        def get_latest_version(self, data, progname, spec, hrefs=False):
             """
             Return the tuple for the latest version of progname, with the most
             preferred archive type if more than one is available of that version.
@@ -595,6 +626,7 @@ def distutils_default():
             message and return None.
             """
             
+            # TODO: incorporate spec into logic
             versions = self.find_archives(data, progname, hrefs)
             return self.latest_sorted_version(versions)
         
@@ -619,7 +651,8 @@ def distutils_default():
                 return self.latest_sorted_version(versions)
             return None
         
-        def get_latest_local_version(self, req, clean=False):
+        def get_latest_local_version(self, req, spec, clean=False):
+            # TODO: incorporate spec into logic
             result = None
             if self.pypi_local and not clean:
                 # Check for a local repository; we assume that pypi_local
@@ -632,10 +665,10 @@ def distutils_default():
                             self.srcdir = srcdir
             return result
         
-        def process_req(self, req, latest_local, link_data=None, clean=False):
+        def process_req(self, req, spec, latest_local, link_data=None, clean=False):
             if (link_data is not None) and (not clean):
                 # Find latest online version and url by looking in link_data
-                latest = self.get_latest_version(link_data, req)
+                latest = self.get_latest_version(link_data, req, spec)
             else:
                 latest = None
             
@@ -657,9 +690,9 @@ def distutils_default():
                         opts = {'.gz': 'z', '.bz2': 'j'}[ext[4:]]
                     except KeyError:
                         opts = ""
-                    unpack_cmd = "tar -x%svf " % opts
+                    unpack_cmd = "tar -x%svf" % opts
                 elif ext == ".zip":
-                    unpack_cmd = "unzip "
+                    unpack_cmd = "unzip"
                 else:
                     unpack_cmd = ""
                 
@@ -700,20 +733,30 @@ def distutils_default():
                 os.chdir("deps")
                 
                 if not clean:
-                    # Unpack the source archive in the deps directory
-                    unpack_dir = "%s-%s" % (req, version)
-                    if os.path.isdir(unpack_dir):
-                        print unpack_dir, "was previously unpacked."
-                    else:
-                        unpack_cmdline = "%s%s" % (unpack_cmd, filename)
-                        print "Executing", unpack_cmdline
-                        os.system(unpack_cmdline)
+                    if unpack_cmd:
+                        # Unpack the source archive in the deps directory
+                        unpack_dir = "%s-%s" % (req, version)
+                        if os.path.isdir(unpack_dir):
+                            print unpack_dir, "was previously unpacked."
+                        else:
+                            unpack_cmdline = "%s %s" % (unpack_cmd, filename)
+                            print "Executing", unpack_cmdline
+                            os.system(unpack_cmdline)
+                    elif "install" in self.setup_opts:
+                        # The archive can be executed directly (exe), but we only
+                        # do this if we're installing
+                        print "Executing", filename
+                        os.system(filename)
+                        unpack_dir = None
                 else:
-                    unpack_dir = [dname for dname in os.listdir(".") if os.path.isdir(dname)
-                        and dname.startswith(req)][0]
+                    unpack_dir = None
+                    for dname in os.listdir("."):
+                        if os.path.isdir(dname) and dname.startswith(req):
+                            unpack_dir = dname
+                            break
                 
                 # Chdir to the source root and run setup with same args as ours
-                if os.path.isdir(unpack_dir):
+                if unpack_dir and os.path.isdir(unpack_dir):
                     os.chdir(unpack_dir)
                     process_cmdline = "python setup.py %s" % self.setup_opts
                     print "Executing", process_cmdline
@@ -743,6 +786,7 @@ def distutils_default():
                 # Now process the requirements
                 for req in self._requires:
                     # TODO: Strip version specifier off end and store
+                    spec = None
                     
                     # First try to import it -- assumes req is an importable name
                     # (we don't do this if cleaning because we may want to clean
@@ -767,33 +811,54 @@ def distutils_default():
                                 self._req_data[req] = link_data
                     
                     # Check local repository if there is one
-                    latest_local = self.get_latest_local_version(req, clean)
+                    latest_local = self.get_latest_local_version(req, spec, clean)
                     
                     if (link_data is not None) or (latest_local is not None):
                         print "Processing requirement %s..." % req
-                        self.process_req(req, latest_local, link_data, clean)
+                        self.process_req(req, spec, latest_local, link_data, clean)
                         continue
                     
                     # If we get here, requirement was not found
                     print >>sys.stderr, \
                         "Could not find requirement %s; program may not run." % req
     
-    return (RequiresHelper, Extension, setup)
+    def setup_wrapper(**kwargs):
+        """ Wrapper for distutils setup function. """
+        if 'name' in kwargs:
+            setup(**kwargs)
+    
+    return (RequiresHelper, Extension, setup_wrapper)
 
 def distutils_setuptools():
     """ Support function for setuptools. """
     
-    from ez_setup import use_setuptools
-    use_setuptools()
+    # Make use of ez_setup optional -- if it's not present, assume that
+    # the packager has ensured setuptools support by some other method
+    try:
+        from ez_setup import use_setuptools
+        use_setuptools()
+    except ImportError:
+        pass
     
     from setuptools import setup
     from setuptools.extension import Extension
     
-    return (None, Extension, setup)
+    def setup_wrapper(**kwargs):
+        """ Wrapper for setuptools setup function. """
+        if 'name' in kwargs:
+            setup(**kwargs)
+        elif 'install_requires' in kwargs:
+            from setuptools.command.easy_install import main
+            sys.argv[0] = "easy_install"
+            opts = sys.argv[1:]
+            for req in kwargs['install_requires']:
+                main([req] + opts)
+    
+    return (None, Extension, setup_wrapper)
 
 # This will be used to process the __license__ variable below
 
-license_map = dict(zip(
+license_map = dict(izip(
     ("PSF", "GNU GPL"), """
 License :: OSI Approved :: Python Software Foundation License
 License :: OSI Approved :: GNU General Public License (GPL)
@@ -816,14 +881,29 @@ Development Status :: 2 - Pre-Alpha
 class SetupHelper(object):
     """ Helper class to manage setup process. """
     
+    setup_vars = [
+        'setup_main',
+        'SetupHelper',
+        '__setup_func__',
+        '__setup_args__',
+        '__post_install__' ]
+    
+    python_builtins = [
+        '__builtins__',
+        '__doc__',
+        '__file__',
+        '__name__',
+        '__package__' ]
+    
     overrides = [
         'distutils_pkg',
-        'ext_class',
-        'non_modules',
-        'requires_class',
-        'setup_func',
         'url_types' ]
     
+    metavars = [
+        'ext_class',
+        'requires_class',
+        'setup_func' ]
+    
     def dir_to_pkg(self, dirname):
         """ Converts relative directory path into dotted package name. """
         return dirname.replace('/', '.')
@@ -847,22 +927,60 @@ class SetupHelper(object):
         # Add variables that might be imported by the setup.py script
         # (because they'll show up in vars) and that we'll generate
         # (or won't erase) but will not want as keyword args to setup
-        internal_vars.extend(['setup_main', 'SetupHelper',
-            '__setup_func__', '__setup_args__', '__post_install__'])
+        internal_vars.extend(self.setup_vars)
         
-        # Get the setup variables passed to us by the setup script
-        for varname, value in vars.iteritems():
-            # Don't change the Python-provided vars
-            if varname not in ('__builtins__', '__doc__', '__file__', '__name__', '__package__'):
-                setattr(self, varname, value)
+        # First transfer variables to our __dict__ from above args
+        self.init_vars(vars, kwargs)
         
-        # Process overrides passed in keyword arguments, and set to None
-        # any variables not otherwise set
-        for varname in self.overrides:
+        # Now process variables from setup.py (we check for a __progname__
+        # first because if it isn't there, we assume we were called from
+        # the setuphelper script and only need to do requires processing
+        if hasattr(self, '__progname__'):
+            self.process_readme()
+            self.process_vars()
+            self.write_manifest()
+            self.process_metadata()
+        
+        # Now do the requires processing
+        self.process_requires()
+        
+        # Now merge the rest of the variables into the setup args; note
+        # that we merge instead of updating so that keyword arguments
+        # passed to the setup script override variables set in its globals
+        for varname in dir(self):
+            if varname not in internal_vars:
+                if varname == '__progname__':
+                    # Special case this one, we can't use __name__ because it is
+                    # a special Python variable for modules already
+                    setup_arg = 'name'
+                else:
+                    # Strip the leading and trailing underscores
+                    setup_arg = varname.strip('_')
+                if setup_arg not in self.__setup_args__:
+                    self.__setup_args__[setup_arg] = getattr(self, varname)
+    
+    def init_vars(self, vars, kwargs):
+        # First remove overrides that won't be used if we're being
+        # called from the setuphelper script
+        overrides = self.overrides[:]
+        metavars = self.metavars[:]
+        if '__progname__' not in vars:
+            overrides.remove('url_types')
+            metavars.remove('ext_class')
+        
+        # Process overrides passed in keyword arguments
+        for varname in (overrides + metavars):
             attrname = '__%s__' % varname
             value = kwargs.pop(varname, None)
-            if (value is not None) or not hasattr(self, attrname):
-                setattr(self, attrname, value)
+            if (value is not None) or (attrname not in vars):
+                vars[attrname] = value
+        
+        # Now get the setup variables passed to us by the setup script
+        # (plus any overrides that were written in above)
+        for varname, value in vars.iteritems():
+            # Don't change the Python-provided vars
+            if varname not in self.python_builtins:
+                setattr(self, varname, value)
         
         # Set defaults by distutils package
         if self.__distutils_pkg__ is None:
@@ -871,7 +989,7 @@ class SetupHelper(object):
             'distutils_%s' % self.__distutils_pkg__)()
         del self.__distutils_pkg__
         # We only set variables that weren't already set above
-        for varname in ('requires_class', 'ext_class', 'setup_func'):
+        for varname in metavars:
             attrname = '__%s__' % varname
             if getattr(self, attrname) is None:
                 setattr(self, attrname, locals()[varname])
@@ -879,35 +997,58 @@ class SetupHelper(object):
         # The keyword args left over are treated as keyword args for the
         # setup function below
         self.__setup_args__ = dict(kwargs)
-        
+    
+    def process_readme(self):
         # crib our long description from the opening section of
         # the README file
-        if hasattr(self, '__start_line__') and hasattr(self, '__end_line__'):
+        if hasattr(self, '__start_line__') or hasattr(self, '__end_line__'):
             if not hasattr(self, '__long_description__'):
+                for attrname in ('__start_line__', '__end_line__'):
+                    if not hasattr(self, attrname):
+                        setattr(self, attrname, None)
+                
+                if isinstance(self.__start_line__, int):
+                    startline = self.__start_line__
+                elif self.__start_line__ is None:
+                    startline = 0
+                else:
+                    startline = None
+                if isinstance(self.__end_line__, int):
+                    endline = self.__end_line__
+                else:
+                    endline = None
+                
                 readme = open("README", 'rU')
-                lines = []
-                lastline = ""
-                started = False
                 try:
-                    for line in readme:
-                        line = line.strip()
-                        if started:
-                            if line == self.__end_line__:
-                                break
-                            else:
-                                lines.append(lastline)
-                        else:
-                            if line == self.__start_line__:
-                                started = True
-                        lastline = line
+                    lines = readme.readlines()
                 finally:
                     readme.close()
-                self.__long_description__ = '\n'.join(lines)
-            del self.__start_line__
-            del self.__end_line__
-        
+                
+                if (endline is not None) and (endline < 0):
+                    endline = endline + len(lines)
+                desclines = []
+                started = False
+                for lineno, line in enumerate(lines):
+                    line = line.rstrip('\n')
+                    if started:
+                        if (lineno == endline) or (line == self.__end_line__):
+                            break
+                        else:
+                            desclines.append(line)
+                    elif (lineno == startline) or (line == self.__start_line__):
+                        desclines.append(line)
+                        started = True
+                
+                self.__long_description__ = '\n'.join(desclines)
+            
+            for attrname in ('__start_line__', '__end_line__'):
+                if hasattr(self, attrname):
+                    delattr(self, attrname)
+    
+    def process_vars(self):
         # We'll store the lines that need to go into MANIFEST.in here (and add
-        # more below if applicable)
+        # more below if applicable) -- note the special-casing of SetupHelper.py
+        # depending on whether it is explicitly listed in py_modules or packages
         self.__manifest_in__ = []
         if not hasattr(self, '__rootfiles__'):
             if hasattr(self, '__py_modules__') and ('SetupHelper' in self.__py_modules__):
@@ -920,7 +1061,8 @@ class SetupHelper(object):
             else:
                 self.__rootdirs__ = ["SetupHelper"]
         for rootfile in self.__rootfiles__:
-            if os.path.isfile(rootfile):
+            # Include glob patterns without checking for file existence
+            if os.path.isfile(rootfile) or ('*' in rootfile) or ('?' in rootfile):
                 self.__manifest_in__.append("include %s\n" % rootfile)
         for rootdir in self.__rootdirs__:
             if os.path.isdir(rootdir):
@@ -938,7 +1080,7 @@ class SetupHelper(object):
             self.__package_root__ = "."
         
         # Figure out the pure Python modules list
-        if self.__non_modules__ is None:
+        if not hasattr(self, '__non_modules__'):
             self.__non_modules__ = []
         if not hasattr(self, '__py_modules__'):
             self.__py_modules__ = [entry[:-3] for entry in os.listdir(self.__package_root__)
@@ -1028,10 +1170,11 @@ class SetupHelper(object):
             if not hasattr(self, '__script_root__'):
                 self.__script_root__ = "scripts"
             if os.path.isdir(self.__script_root__):
-                self.__scripts__.extend("%s/%s" % (directory, filename)
-                    for directory, subdirs, files in os.walk(self.__script_root__)
-                        if not "." in directory
-                    for filename in files if not filename.startswith("."))
+                for directory, subdirs, files in os.walk(self.__script_root__):
+                    if "." not in directory:
+                        for filename in files:
+                            if not filename.startswith("."):
+                                self.__scripts__.append("%s/%s" % (directory, filename))
         if hasattr(self, '__script_root__'):
             del self.__script_root__
         if not hasattr(self, '__data_files__'):
@@ -1046,11 +1189,11 @@ class SetupHelper(object):
                         pathprefix = "lib"
                     else:
                         pathprefix = "share/%s" % self.__progname__
-                    self.__data_files__.extend(("%s/%s" % (pathprefix, directory),
-                        ["%s/%s" % (directory, filename) for filename in files
-                            if not filename.startswith(".")])
-                        for directory, subdirs, files in os.walk(datadir)
-                            if files and not "." in directory)
+                    for directory, subdirs, files in os.walk(datadir):
+                        if files and ("." not in directory):
+                            self.__data_files__.append(("%s/%s" % (pathprefix, directory),
+                                ["%s/%s" % (directory, filename) for filename in files
+                                    if not filename.startswith(".")]))
                     self.__manifest_in__.append("recursive-include %s *.*\n" % datadir)
         if not self.__scripts__:
             del self.__scripts__
@@ -1059,7 +1202,8 @@ class SetupHelper(object):
         if hasattr(self, '__data_dirs__'):
             del self.__data_dirs__
         del self.__package_dirs__
-        
+    
+    def write_manifest(self):
         # Write MANIFEST.in -- tmp file first so we don't clobber the current
         # one if there's a problem
         manifest_in = open("MANIFEST.in.tmp", 'w')
@@ -1073,7 +1217,8 @@ class SetupHelper(object):
         if os.path.isfile("MANIFEST.in.old"):
             os.remove("MANIFEST.in.old")
         del self.__manifest_in__
-        
+    
+    def process_metadata(self):
         # If version is a tuple, convert to a string (need to do this before
         # the URLs are determined)
         if isinstance(self.__version__, tuple):
@@ -1092,7 +1237,7 @@ class SetupHelper(object):
                 self.__url_ext__ = 'tar.gz'
             else:
                 if self.__url_types__ is None:
-                    self.__url_types__ = {'posix': "tar.gz", 'nt': "zip", 'mac': "dmg"}
+                    self.__url_types__ = {'posix': "tar.gz", 'nt': "zip"}
                 try:
                     self.__url_ext__ = self.__url_types__[self.__url_type__]
                 except KeyError:
@@ -1136,17 +1281,24 @@ class SetupHelper(object):
         
         # Sort classifiers (not necessary, but looks better)
         self.__classifiers__.sort()
-        
+    
+    def process_requires(self):
         # Grab setup options from our sys.argv so we can use the same
         # ones when processing requirements
-        setup_opts = " ".join([opt for opt in sys.argv if opt not in ("python", "setup.py")])
+        setup_opts = " ".join([opt for opt in sys.argv[1:] if opt not in ("python", "setup.py")])
         
-        # Check to see if we need to even process requirements
-        do_requires = False
-        for cmd in ("build", "clean", "install"):
-            if cmd in setup_opts:
-                do_requires = True
-                break
+        if hasattr(self, '__progname__'):
+            # Check to see if we need to even process requirements
+            do_requires = False
+            for cmd in ("build", "clean", "install"):
+                if cmd in setup_opts:
+                    do_requires = True
+                    break
+        else:
+            # If no progname, we're being called by setuphelper, always do requires,
+            # and prefix "install" to setup options
+            setup_opts = "install %s" % setup_opts
+            do_requires = True
         
         if hasattr(self, '__install_requires__'):
             # We need to copy the variable name here so it will show up in PKG-INFO
@@ -1161,21 +1313,6 @@ class SetupHelper(object):
                 # We can now delete this variable since it's not used in standard distutils
                 del self.__install_requires__
         del self.__requires_class__
-        
-        # Now merge the rest of the variables into the setup args; note
-        # that we merge instead of updating so that keyword arguments
-        # passed to the setup script override variables set in its globals
-        for varname in dir(self):
-            if varname not in internal_vars:
-                if varname == '__progname__':
-                    # Special case this one, we can't use __name__ because it is
-                    # a special Python variable for modules already
-                    setup_arg = 'name'
-                else:
-                    # Strip the leading and trailing underscores
-                    setup_arg = varname.strip('_')
-                if setup_arg not in self.__setup_args__:
-                    self.__setup_args__[setup_arg] = getattr(self, varname)
     
     def do_setup(self):
         """
@@ -1194,9 +1331,10 @@ class SetupHelper(object):
         """
         
         if hasattr(self, '__post_install__') and self.__post_install__:
-            print "Running post-install scripts..."
+            print "Running post-install scripts in %s ..." % install_scripts_dir
             for scriptname in self.__post_install__:
-                os.system(scriptname)
+                # Use ugly hack above to get script dir from distutils to be sure we're grabbing the right script
+                os.system(os.path.join(install_scripts_dir, scriptname))
 
 # TODO: convert long option of the form --<option-name>=<value> to keyword argument option_name=value
 
