@@ -1,7 +1,7 @@
 #!/usr/bin/env python
 """
 PXMLVIEW.PY
-Copyright (C) 2008 by Peter A. Donis
+Copyright (C) 2008-2009 by Peter A. Donis
 
 Released under the GNU General Public License, Version 2
 See the LICENSE and README files for more information
@@ -12,6 +12,10 @@ A simple read-only XML file viewer using the PLIB package.
 import sys
 import os
 
+from plib import __version__
+
+from plib.utils import version
+
 from plib.xml import classes
 from plib.xml import io
 from plib.gui import main as gui
@@ -44,8 +48,8 @@ class XMLColsTag(classes.BaseElement):
         return "element"
     
     def _get_cols(self):
-        return [" ".join([self.tag] + ["%s='%s'" % (key, self.get(key)) for key in self.keys()]),
-            self.tagtype()]
+        return [" ".join([self.tag] + ["%s='%s'" % (key, self.get(key))
+            for key in self.keys()]), self.tagtype()]
     
     cols = property(_get_cols)
     
@@ -57,7 +61,7 @@ class XMLColsTag(classes.BaseElement):
 
 class XMLListViewItem(gui.PListViewItem):
     
-    def __init__(self, parent, index, node, after=None):
+    def __init__(self, parent, index, node):
         """ Put data in the form that PListViewItem expects to see. """
         if (len(node) == 0) and (node.cdata() is not None):
             childlist = [node.cdata()]
@@ -66,7 +70,7 @@ class XMLListViewItem(gui.PListViewItem):
         else:
             childlist = None
         data = (node.cols, childlist)
-        gui.PListViewItem.__init__(self, parent, index, data, after)
+        gui.PListViewItem.__init__(self, parent, index, data)
         self.expand()
 
 class XMLListView(gui.PListView, gui.PEditor):
@@ -77,10 +81,19 @@ class XMLListView(gui.PListView, gui.PEditor):
     def __init__(self, parent, data):
         gui.PEditor.__init__(self, parent, data=data)
         gui.PListView.__init__(self, parent,
-            [gui.PHeaderLabel("XML"), gui.PHeaderLabel("Node Type", 150)],
+            [gui.PHeaderLabel("XML"), gui.PHeaderLabel("Node Type", 150, ALIGN_CENTER)],
             [self._xml.getroot()],
             self.current_changed)
     
+    # FIXME: Figure out a way to have the editor classes automatically detect this
+    if hasattr(gui.PListView, 'edit'):
+        
+        def edit(self, *args):
+            # Distinguish between edit method of PListView and edit method of PEditor
+            if len(args) > 0:
+                return gui.PListView.edit(self, *args)
+            return gui.PEditor.edit(self)
+    
     def _gettype(self):
         return "XML File"
     
@@ -129,6 +142,7 @@ class XMLTabWidget(gui.PTabWidget):
             self.add_file(fname)
     
     def tab_changed(self, widget):
+        # FIXME: Make the control handle this properly
         if self._loaded and not self._closing:
             # Only fire the event handler after initial data load
             self.print_status(widget.data)
@@ -138,7 +152,7 @@ class XMLTabWidget(gui.PTabWidget):
 
 PXMLViewerAboutData = {
     'name': "PXMLViewer",
-    'version': "0.2",
+    'version': version.version_string(__version__),
     'copyright': "Copyright (C) 2008",
     'license': "GNU General Public License (GPL) Version 2",
     'description': "XML File Viewer", 
@@ -152,7 +166,7 @@ class PXMLViewer(gui.PMainWindow):
     actionflags = [ACTION_FILEOPEN, ACTION_ABOUT, ACTION_EXIT]
     clientwidgetclass = XMLTabWidget
     defaultcaption = "XML File Viewer"
-    maximized = True
+    placement = (SIZE_MAXIMIZED, MOVE_NONE)
     queryonexit = False
     
     # FIXME: Figure out how to mask the tab change event on shutdown so this
