@@ -1,102 +1,76 @@
 #!/usr/bin/env python
 """
 PYIDSERVER-GUI.PY
-Copyright (C) 2008 by Peter A. Donis
+Copyright (C) 2008-2009 by Peter A. Donis
 
 Released under the GNU General Public License, Version 2
 See the LICENSE and README files for more information
 
-GUI for Python implementation of IDServer.
-See PYIDSERVER.PY for more information.
+GUI for Python implementation of IDServer. See
+PYIDSERVER.PY for more information.
 """
 
 import os
 
+from plib import __version__
+
+from plib.utils import version
+
 from plib.gui import main as gui
 from plib.gui import common
 from plib.gui.defs import *
 
-import pyidserver
-
-offset = 4
-combowidth = 90
-buttonwidth = 110
-outputheight = 400
-
-framemargin = 10
-panelspacing = 10
-
-class IDServerOutputFile(object):
-    """
-    File-like object to redirect output to text control. Note
-    that 'file-like' is used very loosely; this object only
-    implements the minimum necessary to work with idserver.
-    """
-    
-    def __init__(self, control):
-        self.control = control
-    
-    def write(self, data):
-        data = "".join([self.control.edit_text, data])
-        self.control.edit_text = data
-    
-    def flush(self):
-        self.control.update()
-
-# Monkey patch common definitions
-
 common.actiondict[ACTION_OK][1] = "&Go"
 
-# Nested child lists for panels
+from plib.gui import specs
+specs.mainwidth = 400
+specs.mainheight = 300
+del specs
+from plib.gui.specs import *
 
-button_geometry = (None, None, buttonwidth, None)
-combo_geometry = (None, None, combowidth, None)
-output_geometry = (None, None, None, outputheight)
+import pyidserver
+
+# Nested child lists for panels
 
 IDServerPadding = [] # equates to an empty panel when processed
 
 IDServerTopLeft = [
-    (gui.PEditBox, (), {}, 'edit_url') ]
-IDServerTopRight = [ (gui.PButton, (ACTION_OK, ""), {'geometry': button_geometry}, 'button_go') ] 
-IDServerTopPanel = [ 
-    (IDServerTopLeft, (), {'align': ALIGN_JUST, 'layout': LAYOUT_HORIZONTAL},
-        'panel_left'),
-    (IDServerTopRight, (), {'align': ALIGN_RIGHT, 'layout': LAYOUT_HORIZONTAL,
-        'margin': offset}, 'panel_right') ]
+    get_editbox('url') ]
+IDServerTopRight = [
+    get_action_button(ACTION_OK, 'go') ]
+IDServerTopPanel = [
+    get_interior_panel(IDServerTopLeft, ALIGN_JUST, LAYOUT_HORIZONTAL, 'left'),
+    get_interior_panel(IDServerTopRight, ALIGN_RIGHT, LAYOUT_HORIZONTAL, 'right') ]
 
 IDServerMainControls = [
-    (gui.PCheckBox, ("DNS Only",), {}, 'checkbox_dnsonly'),
-    (gui.PCheckBox, ("Set Protocol",), {}, 'checkbox_protocol'),
-    (gui.PComboBox, (sorted(pyidserver.protocols.keys()),), {'geometry': combo_geometry},
-        'combo_protocol'),
-    (gui.PCheckBox, ("Set Port",), {}, 'checkbox_portnum') ]
+    get_checkbox("DNS Only", 'dnsonly'),
+    get_checkbox("Set Protocol", 'protocol'),
+    get_combobox(sorted(pyidserver.protocols.iterkeys()), 'protocol'),
+    get_checkbox("Set Port", 'portnum') ]
 IDServerMainEdit = [
-    (gui.PEditBox, (), {'expand': False}, 'edit_portnum') ]
+    get_numeditbox('portnum', False) ]
 IDServerMainHeader = [
-    (IDServerMainControls, (), {'align': ALIGN_LEFT, 'layout': LAYOUT_HORIZONTAL,
-        'margin': offset, 'spacing': panelspacing}, 'panel_controls'),
-    (IDServerMainEdit, (), {'align': ALIGN_LEFT, 'layout': LAYOUT_HORIZONTAL},
-        'panel_edit'),
-    (IDServerPadding, (), {}, 'padding_main') ]
+    get_toplevel_panel(IDServerMainControls, ALIGN_LEFT, LAYOUT_HORIZONTAL, 'controls'),
+    get_interior_panel(IDServerMainEdit, ALIGN_LEFT, LAYOUT_HORIZONTAL, 'edit'),
+    get_padding('main') ]
 IDServerMainBody = [
-    (gui.PEditControl, (), {'geometry': output_geometry, 'scrolling': True}, 'text_output') ]
-IDServerMainPanel = [ 
-    (IDServerMainHeader, (), {'align': ALIGN_TOP, 'layout': LAYOUT_HORIZONTAL,
-        'spacing': panelspacing}, 'panel_header'),
-    (IDServerMainBody, (), {'align': ALIGN_JUST, 'layout': LAYOUT_VERTICAL}, 'panel_body') ]
+    get_textdisplay('output') ]
+IDServerMainPanel = [
+    get_midlevel_panel(IDServerMainHeader, ALIGN_TOP, LAYOUT_HORIZONTAL, 'header'),
+    get_interior_panel(IDServerMainBody, ALIGN_JUST, LAYOUT_VERTICAL, 'body') ]
 
 IDServerBottomPanel = [
-    (gui.PButton, (ACTION_ABOUT, ""), {'geometry': button_geometry}, 'button_about'), # 
-    (gui.PButton, (ACTION_EXIT, ""), {'geometry': button_geometry}, 'button_quit'),
-    (IDServerPadding, (), {}, 'padding_bottom') ]
+    get_action_button(ACTION_ABOUT, 'about'),
+    get_action_button(ACTION_EXIT, 'quit'),
+    get_padding('bottom') ]
 
 # Helper function for patching frame event handlers into above gui specs
 def _update_obj(klass, index, target):
-    klass[index][2].update({'target': target})
+    klass[index][2]['target'] = target
 
 IDServerAboutData = {
     'name': "PyIDServer",
-    'version': "0.2",
+    'version': version.version_string(__version__),
     'copyright': "Copyright (C) 2008",
     'license': "GNU General Public License (GPL) Version 2",
     'description': "A Python GUI for IDServer", 
@@ -104,22 +78,17 @@ IDServerAboutData = {
     'website': "http://www.peterdonis.net",
     'icon': os.path.join(os.path.split(os.path.realpath(__file__))[0], "pyidserver.png") }
 
-class IDServerFrame(gui.PAutoPanel):
+class IDServerFrame(gui.PMainPanel):
     
     aboutdata = IDServerAboutData
     defaultcaption = "PyIDServer"
+    layout = LAYOUT_VERTICAL
+    placement = (SIZE_CLIENTWRAP, MOVE_CENTER)
     
-    childlist = [ 
-        (IDServerTopPanel, (), {'align': ALIGN_TOP, 'layout': LAYOUT_HORIZONTAL,
-            'spacing': panelspacing}, 'panel_top'),
-        (IDServerMainPanel, (), {'align': ALIGN_JUST, 'layout': LAYOUT_VERTICAL,
-            'spacing': panelspacing}, 'panel_main'),
-        (IDServerBottomPanel, (), {'align': ALIGN_BOTTOM, 'layout': LAYOUT_HORIZONTAL,
-            'margin': offset, 'spacing': panelspacing}, 'panel_bottom') ]
-    
-    def __init__(self, parent):
-        gui.PAutoPanel.__init__(self, parent, layout=LAYOUT_VERTICAL,
-            margin=framemargin, spacing=panelspacing)
+    childlist = [
+        get_toplevel_panel(IDServerTopPanel, ALIGN_TOP, LAYOUT_HORIZONTAL, 'top'),
+        get_toplevel_panel(IDServerMainPanel, ALIGN_JUST, LAYOUT_VERTICAL, 'main'),
+        get_toplevel_panel(IDServerBottomPanel, ALIGN_BOTTOM, LAYOUT_HORIZONTAL, 'bottom') ]
     
     def _createpanels(self):
         # Monkey patch widget creation parameters with our events
@@ -129,11 +98,12 @@ class IDServerFrame(gui.PAutoPanel):
         _update_obj(IDServerBottomPanel, 1, self._parent.exit)
         
         # Connect control signals for sync of user interface
+        _update_obj(IDServerMainControls, 0, self.dns_check)
         _update_obj(IDServerMainControls, 1, self.protocol_check)
         _update_obj(IDServerMainControls, 3, self.portnum_check)
         
         # Create child widgets
-        super(gui.PAutoPanel, self)._createpanels()
+        super(IDServerFrame, self)._createpanels()
         
         # Adjust some widget parameters that couldn't be set in constructors
         self.edit_url.setup_notify(SIGNAL_ENTER, self.go)
@@ -146,14 +116,25 @@ class IDServerFrame(gui.PAutoPanel):
         self.edit_portnum.edit_text = str(portnum)
         self.portnum_check()
         self.text_output.set_font("Courier New")
-        self.text_output.readonly = True
+        #self.text_output.readonly = True
         
         # Set up output file-like object here for convenience
-        self.outputfile = IDServerOutputFile(self.text_output)
+        self.outputfile = gui.PTextFile(self.text_output)
+        
+        # Set up a callback for the idserver async polling loop to keep the GUI running
+        pyidserver.run_callback = self._parent.app.process_events
         
         # Start with keyboard focus in the URL text entry
         self.edit_url.set_focus()
     
+    def dns_check(self):
+        """ Only enable protocol and port controls if not DNS only. """
+        enable = not self.checkbox_dnsonly.checked
+        for ctrl, subctrl in ((self.checkbox_protocol, self.combo_protocol),
+            (self.checkbox_portnum, self.edit_portnum)):
+                ctrl.enabled = enable
+                subctrl.enabled = enable and ctrl.checked
+    
     def protocol_check(self):
         """ Sync protocol combo enable with check box """
         self.combo_protocol.enabled = self.checkbox_protocol.checked
@@ -170,12 +151,13 @@ class IDServerFrame(gui.PAutoPanel):
         """ Go button was pushed or Enter key was pressed, execute query """
         
         # Clear output
-        self.text_output.edit_text = ""
+        self.outputfile.truncate(0)
         
         # Check URL
         url = self.edit_url.edit_text
         if len(url) < 1:
-            self.text_output.edit_text = "Error: No URL entered."
+            self.outputfile.write("Error: No URL entered.")
+            self.outputfile.flush()
             return
         
         # Hack to grab default values from function in pyidserver
