@@ -1,27 +1,32 @@
 #!/usr/bin/env python
 """
 PYIDSERVER.PY
-Copyright (C) 2008 by Peter A. Donis
+Copyright (C) 2008-2009 by Peter A. Donis
 
 Released under the GNU General Public License, Version 2
 See the LICENSE and README files for more information
 
-Python implementation of IDServer, a
-command-line tool to query an internet
-server and return information about it.
+Python implementation of IDServer, a command-line tool
+to query an internet server and return information
+about it.
 """
 
 import sys
 import socket
 
-from plib.utils import options
+from plib.stdlib.options import parse_options
+from plib.utils.chatgen import chat_replies
+
+def do_output(fileobj, s, linesep=True):
+    if linesep:
+        fileobj.write("%s\n" % s)
+    else:
+        fileobj.write(s)
+    fileobj.flush()
+
+run_callback = None # used by pyidserver-gui
 
 PROTO_DEFAULT = 'http'
-BUFSIZE = 4096
-
-def do_output(fileobj, s):
-    fileobj.write(s)
-    fileobj.flush()
 
 quitmsgs = [None, "QUIT\r\n"]
 
@@ -64,30 +69,30 @@ def run_idserver(fileobj, arg, dns_only, protocol, portnum):
         if (addrtype in protocols):
             if protocol:
                 do_output(fileobj,
-                    "URL includes protocol %s, ignoring specified protocol %s.\n"
+                    "URL includes protocol %s, ignoring specified protocol %s."
                     % (addrtype, protocol))
             protocol = addrtype
         elif addrtype:
-            do_output(fileobj, "URL includes incorrect protocol %s, ignoring.\n"
+            do_output(fileobj, "URL includes incorrect protocol %s, ignoring."
                 % addrtype)
     if '/' in arg:
         arg, path = arg.split('/')
         if path:
-            do_output(fileobj, "URL includes path after host name/address, ignoring.\n")
+            do_output(fileobj, "URL includes path after host name/address, ignoring.")
     if ':' in arg:
         arg, portstr = arg.split(':')
         try:
             p = int(portstr)
             if p != portnum:
                 if portnum != 0:
-                    do_output(fileobj, "URL includes port %d, ignoring specified port %d.\n"
+                    do_output(fileobj, "URL includes port %d, ignoring specified port %d."
                         % (p, portnum))
                 portnum = p
         except ValueError:
-            do_output(fileobj, "URL includes invalid port %s, ignoring.\n" % portstr)
+            do_output(fileobj, "URL includes invalid port %s, ignoring." % portstr)
     
     if dns_only:
-        do_output(fileobj, "Doing DNS lookup on %s ...\n" % arg)
+        do_output(fileobj, "Doing DNS lookup on %s ..." % arg)
     else:
         proto_msg = port_msg = ""
         if protocol == "":
@@ -102,33 +107,28 @@ def run_idserver(fileobj, arg, dns_only, protocol, portnum):
             else:
                 port_msg = " on port %i" % portnum
         else:
-            raise ValueError, "Invalid protocol: %s.\n" % protocol
+            raise ValueError, "Invalid protocol: %s." % protocol
     
     ipaddr = socket.gethostbyname(arg)
     if ipaddr == arg:
         # URL was an IP address, reverse lookup
         url = socket.gethostbyaddr(ipaddr)[0]
-        do_output(fileobj, "Domain name for %s is %s.\n" % (ipaddr, url))
+        do_output(fileobj, "Domain name for %s is %s." % (ipaddr, url))
     else:
         # URL was a domain name, normal lookup
         url = arg
-        do_output(fileobj, "IP address for %s is %s.\n" % (url, ipaddr))
+        do_output(fileobj, "IP address for %s is %s." % (url, ipaddr))
     
     if not dns_only:
-        do_output(fileobj, "Contacting %s%s%s ...\n" % (arg, proto_msg, port_msg))
-        sock = socket.socket(socket.AF_INET, socket.SOCK_STREAM)
-        sock.connect((url, portnum))
-        do_output(fileobj, "Connected ...\n")
         replied = False
-        for item in proto_items:
-            if item is not None:
-                sock.sendall(item)
+        do_output(fileobj, "Contacting %s%s%s ..." % (arg, proto_msg, port_msg))
+        for reply in chat_replies((url, portnum), proto_items, run_callback):
             if not replied:
-                do_output(fileobj, "Server returned the following:\n")
                 replied = True
-            do_output(fileobj, sock.recv(BUFSIZE))
-        sock.close()
-        do_output(fileobj, "Connection closed.\n")
+                do_output(fileobj, "Connected ...")
+                do_output(fileobj, "Server returned the following:")
+            do_output(fileobj, reply, False)
+        do_output(fileobj, "Connection closed.")
 
 def run_main(outfile, arg, errfile=None, dns_only=False, protocol="", portnum=0):
     if errfile is None:
@@ -136,8 +136,8 @@ def run_main(outfile, arg, errfile=None, dns_only=False, protocol="", portnum=0)
     try:
         run_idserver(outfile, arg, dns_only, protocol, portnum)
     except ValueError:
-        errfile.write(str(sys.exc_info()[1]))
-    except (socket.error, socket.herror, socket.gaierror, socket.timeout):
+        errfile.write("%s\n" % str(sys.exc_info()[1]))
+    except (ValueError, socket.error, socket.herror, socket.gaierror, socket.timeout):
         exc_type, exc_value, _ = sys.exc_info()
         errfile.write("%s %s\n" % tuple(map(str, (exc_type, exc_value))))
 
@@ -156,5 +156,5 @@ if __name__ == '__main__':
         )
     arglist = ["URL"]
     
-    opts, args = options.parse_options(optlist, arglist)
+    opts, args = parse_options(optlist, arglist)
     run_main(sys.stdout, args[0], sys.stderr, opts.dns_only, opts.protocol, opts.portnum)
