@@ -1,7 +1,7 @@
 #!/usr/bin/env python
 """
 Sub-Package CLASSES of Package PLIB -- Python Class Objects
-Copyright (C) 2008 by Peter A. Donis
+Copyright (C) 2008-2009 by Peter A. Donis
 
 Released under the GNU General Public License, Version 2
 See the LICENSE and README files for more information
@@ -43,7 +43,16 @@ PLIB.GUI sub-package) can make the gain much greater.
 import os
 import glob
 
-from ModuleProxy import ModuleProxy
+from plib.utils import ModuleProxy
+
+# We define these here because after the ModuleProxy they
+# wouldn't be directly importable from StateMachine.py
+
+class StateMachineException(Exception): pass
+
+class InvalidState(StateMachineException): pass
+class InvalidInput(StateMachineException): pass
+class RecursiveTransition(StateMachineException): pass
 
 # Helper function to actually do the import when the
 # module attribute is accessed; note that it assumes
