@@ -2,7 +2,7 @@
 """
 Module APP -- GUI Application Classes
 Sub-Package GUI.BASE of Package PLIB -- Python GUI Framework
-Copyright (C) 2008 by Peter A. Donis
+Copyright (C) 2008-2009 by Peter A. Donis
 
 Released under the GNU General Public License, Version 2
 See the LICENSE and README files for more information
@@ -10,6 +10,8 @@ See the LICENSE and README files for more information
 Defines the classes that form the basic GUI application framework.
 """
 
+from plib.gui.defs import *
+
 class PAboutDialogBase(object):
     """
     Base class for about dialogs; allows mapping of standard fields
@@ -69,6 +71,9 @@ class PTopWindowBase(object):
     
     maximized -- whether this window should be maximized
     
+    clientwrap -- whether this window should be sized just large enough to wrap
+    its client widget
+    
     aboutdata -- gives data for display in the 'about' dialog.
     """
     
@@ -76,17 +81,25 @@ class PTopWindowBase(object):
     defaultcaption = "Top Window"
     clientwidgetclass = None
     aboutdialogclass = None
+    placement = (SIZE_NONE, MOVE_NONE)
     sizeoffset = 160
-    centered = True
-    sized = True
-    maximized = False
     
-    _clientattrs = ('aboutdata', 'defaultcaption', 'sizeoffset', 'centered',
-        'sized', 'maximized')
+    _clientattrs = ('aboutdata', 'defaultcaption', 'sizeoffset', 'placement')
     
     def __init__(self, parent, cls=None):
         self.shown = False
-        self.app = parent
+        
+        # Figure out if parent is another window or the application
+        if hasattr(parent, 'app'):
+            self.app = parent.app
+            self._parent = parent
+        elif isinstance(parent, PApplicationBase):
+            self.app = parent
+            self._parent = None
+        else:
+            # This shouldn't happen, but just in case...
+            self.app = None
+            self._parent = None
         
         self._set_client_class(cls)
         
@@ -101,9 +114,11 @@ class PTopWindowBase(object):
             for attrname in self._clientattrs:
                 if hasattr(cls, attrname):
                     setattr(self, attrname, getattr(cls, attrname))
+                elif not hasattr(self, attrname):
+                    setattr(self, attrname, None)
     
     def set_caption(self, caption):
-        """ Placeholder for derived classes to implement """
+        """ Placeholder for derived classes to implement. """
         pass
     
     def createclient(self):
@@ -132,9 +147,13 @@ class PTopWindowBase(object):
         """ Should always call from derived classes to ensure proper setup """
         if not self.shown:
             # Do placement just before showing for first time
-            if self.sized:
-                self.sizetoscreen(self.maximized)
-            if self.centered and not self.maximized:
+            size, pos = self.placement
+            if size == SIZE_CLIENTWRAP:
+                c = self.clientwidget
+                self.sizetoclient(c.preferred_width(), c.preferred_height())
+            elif size in (SIZE_MAXIMIZED, SIZE_OFFSET):
+                self.sizetoscreen(size == SIZE_MAXIMIZED)
+            if (pos == MOVE_CENTER) and (size != SIZE_MAXIMIZED):
                 self.center()
             self.shown = True
     
@@ -147,7 +166,6 @@ class PTopWindowBase(object):
     
     def acceptclose(self):
         """ Return False if window should not close based on current state. """
-        
         return True
     
     def exit(self):
