@@ -2,7 +2,7 @@
 """
 Module MAINWIN -- GUI Main Window Classes
 Sub-Package GUI.BASE of Package PLIB -- Python GUI Framework
-Copyright (C) 2008 by Peter A. Donis
+Copyright (C) 2008-2009 by Peter A. Donis
 
 Released under the GNU General Public License, Version 2
 See the LICENSE and README files for more information
@@ -159,8 +159,8 @@ class PMainWindowBase(app.PTopWindowBase):
     queryonexit = True
     
     editlist = [ACTION_EDIT]
-    pendinglist = [ACTION_OK, ACTION_CANCEL]
-    modifiedlist = [ACTION_FILESAVE]
+    pendinglist = [ACTION_APPLY, ACTION_COMMIT, ACTION_OK, ACTION_CANCEL]
+    modifiedlist = [ACTION_FILESAVE, ACTION_FILESAVEAS]
     
     _clientattrs = app.PTopWindowBase._clientattrs + ('actionflags',
         'large_icons', 'show_labels', 'queryonexit')
@@ -169,6 +169,7 @@ class PMainWindowBase(app.PTopWindowBase):
         # We don't call up to PTopWindowBase.__init__ here
         # because we want to do things in a slightly
         # different order when there are more frills
+        
         self.shown = False
         self.actions = {}
         self.app = parent
@@ -278,7 +279,7 @@ class PMainWindowBase(app.PTopWindowBase):
     def getfiledialog(self, path="", filter="", action=ACTION_FILEOPEN):
         if action == ACTION_FILEOPEN:
             return self.filedialog.openfiledialog(path, filter)
-        if action == ACTION_FILESAVE:
+        if action == ACTION_FILESAVEAS:
             return self.filedialog.savefiledialog(path, filter)
         return ""
     
@@ -297,8 +298,6 @@ class PMainWindowBase(app.PTopWindowBase):
         """ Return False if window should not close based on current state """
         
         accept = self.editorcanclose()
-        if self.app.mainwin == self:
-            return accept and ((not self.queryonexit)
-                or (self.queryexit() == answerOK))
-        else:
-            return accept
+        if accept and (self.app.mainwin == self):
+            accept = ((not self.queryonexit) or (self.queryexit() == answerOK))
+        return accept
