@@ -2,7 +2,7 @@
 """
 Internal Module _GUI
 Sub-Package GUI of Package PLIB -- Python GUI Framework
-Copyright (C) 2008 by Peter A. Donis
+Copyright (C) 2008-2009 by Peter A. Donis
 
 Released under the GNU General Public License, Version 2
 See the LICENSE and README files for more information
@@ -17,9 +17,30 @@ variable in its namespace.
 import sys
 import os
 
-from plib.gui.defs import *
+from plib.gui.defs import GUI_KDE, GUI_QT, GUI_GTK, GUI_WX, GUI_KDE4, GUI_QT4
 from plib.gui._setup import *
 
+# This variable is provided so that if you want to test your own toolkit that's
+# not in the supported list, you can still use the other facilities; you just
+# need to import this module and set this variable to True before importing
+# plib.gui.main. However, note that if you do this, *none* of the standard GUI
+# widget classes will be available unless you add them yourself; you can do this
+# by setting attributes on this module before importing plib.gui.main, or by
+# constructing all your widgets "by hand". The former technique has the advantage
+# of allowing you to use PLIB.GUI's other built-in facilities, but it requires you
+# to provide classes with all the appropriate names yourself (they can be dummy
+# classes if you won't use them, but they must be there). For example:
+#
+# from plib.gui import _gui
+# _gui.gui_test = True
+# _gui.PApplication = PMyApplication # assuming this was defined earlier
+# _gui.PTopWindow = PMyTopWindow
+# ... etc. for all other GUI widget classes
+#
+# Once you do this, you can use the rest of PLIB.GUI normally, including classes
+# like PAutoPanel that allow you to define GUI specs declaratively.
+gui_test = False
+
 # GUI toolkit determination -- this has to be here to avoid circular imports
 # among the various GUI modules
 gui_toolkit = 0
@@ -35,6 +56,7 @@ if env_toolkit_name is not None:
             if name == env_toolkit_name:
                 gui_toolkit = getattr(sys.modules[__name__], name)
                 break
+        del name
 
 # Clean up namespace
 del env_toolkit_name
@@ -45,25 +67,32 @@ if gui_toolkit == 0:
     window_mgr = os.getenv('WINDOWMANAGER')
     
     # check KDE/Qt first
-    if KDE_PRESENT or QT_PRESENT:
-        kde_session = os.environ.has_key('KDE_FULL_SESSION')
+    if KDE_PRESENT or QT_PRESENT or KDE4_PRESENT or QT4_PRESENT:
+        kde_session = 'KDE_FULL_SESSION' in os.environ
         kde_desktop = (desktop_session == 'kde')
         kde_winmgr = isinstance(window_mgr, basestring) and (window_mgr.find('kde') > -1)
         # TODO: check if kdeinit (kde root process) and kwin (kde window mgr) are running
         
-        # if KDE is running, default to KDE if PyKDE is present, otherwise Qt
+        # if KDE is running, default to KDE if PyKDE is present, otherwise Qt; but make
+        # sure the versions match
         if kde_session or kde_desktop or kde_winmgr:
-            if KDE_PRESENT:
-                gui_toolkit = GUI_KDE
+            if os.getenv('KDE_SESSION_VERSION') == '4':
+                if KDE4_PRESENT:
+                    gui_toolkit = GUI_KDE4
+                else:
+                    gui_toolkit = GUI_QT4
             else:
-                gui_toolkit = GUI_QT
+                if KDE_PRESENT:
+                    gui_toolkit = GUI_KDE
+                else:
+                    gui_toolkit = GUI_QT
         
         # clean up namespace
         del kde_session, kde_desktop, kde_winmgr
     
     # check GTK if KDE/Qt didn't work
     if (gui_toolkit == 0) and GTK_PRESENT:
-        gnome_session = os.environ.has_key('GNOME_DESKTOP_SESSION_ID')
+        gnome_session = 'GNOME_DESKTOP_SESSION_ID' in os.environ
         gnome_desktop = (desktop_session == 'gnome')
         gnome_winmgr = isinstance(window_mgr, basestring) and (window_mgr.find('gnome') > -1)
         # TODO: check if gconfd running and if /desktop/gnome/applications/browser key present
@@ -77,13 +106,19 @@ if gui_toolkit == 0:
         # clean up namespace
         del gnome_session, gnome_desktop, gnome_winmgr
     
+    # check Qt 4 if none of the above worked
+    if (gui_toolkit == 0) and QT4_PRESENT:
+        gui_toolkit = GUI_QT4
+    
+    # check Qt if none of the above worked
+    if (gui_toolkit == 0) and QT_PRESENT:
+        gui_toolkit = GUI_QT
+    
     # default to wxWidgets if present
     if (gui_toolkit == 0) and WX_PRESENT:
         gui_toolkit = GUI_WX
     
     # clean up namespace
     del desktop_session, window_mgr
-    
-    # if no toolkit found, error
-    if gui_toolkit == 0:
-        sys.exit("No GUI toolkit found; cannot run GUI application.")
+
+del sys, os
