@@ -2,7 +2,7 @@
 """
 Module GTKAPP -- Python GTK Application Objects
 Sub-Package GUI.TOOLKITS.GTK of Package PLIB -- Python GUI Toolkits
-Copyright (C) 2008 by Peter A. Donis
+Copyright (C) 2008-2009 by Peter A. Donis
 
 Released under the GNU General Public License, Version 2
 See the LICENSE and README files for more information
@@ -14,11 +14,12 @@ import pygtk
 pygtk.require('2.0')
 import gtk
 import gtk.gdk
+import gobject
 
 from plib.gui.defs import *
 from plib.gui._base import app
 
-from _gtkcommon import _PGtkCommunicator
+from _gtkcommon import _PGtkCommunicator, _gtksignals
 
 class PGtkAboutDialog(app.PAboutDialogBase, gtk.AboutDialog):
     
@@ -49,6 +50,13 @@ class _PGtkMainMixin(gtk.Window, _PGtkCommunicator):
     
     aboutdialogclass = PGtkAboutDialog
     
+    # Define closing signal using 'automagic' class field
+    
+    # Need to define the 'enter' signal for Entry
+    __gsignals__ = { _gtksignals[SIGNAL_CLOSING]:
+        (gobject.SIGNAL_RUN_LAST,
+        gobject.TYPE_NONE, ()) }
+    
     def __init__(self):
         gtk.Window.__init__(self, gtk.WINDOW_TOPLEVEL)
         
@@ -85,6 +93,12 @@ class _PGtkMainMixin(gtk.Window, _PGtkCommunicator):
         return self.get_size()[0]
     w = property(_get_w)
     
+    def _show_window(self):
+        gtk.Window.show(self)
+    
+    def _hide_window(self):
+        gtk.Window.hide(self)
+    
     def set_caption(self, caption):
         self.set_title(caption)
     
@@ -100,7 +114,7 @@ class _PGtkMainMixin(gtk.Window, _PGtkCommunicator):
     
     def center(self):
         width, height = self.get_size()
-        self.move((gtk.gdk.screen_width() - width) / 2, \
+        self.move((gtk.gdk.screen_width() - width) / 2,
             (gtk.gdk.screen_height() - height) / 2)
     
     def show_init(self):
@@ -110,6 +124,8 @@ class _PGtkMainMixin(gtk.Window, _PGtkCommunicator):
         # 'automagic' method to fake SIGNAL_QUERYCLOSE when window closes in
         # response to a program signal (wtf isn't this a method in the GTK API?)
         if not self.emit("delete_event", gtk.gdk.Event(gtk.gdk.DELETE)):
+            # Send the closing signal
+            self.do_notify(SIGNAL_CLOSING)
             self.destroy()
     
     def delete_event(self):
@@ -118,7 +134,7 @@ class _PGtkMainMixin(gtk.Window, _PGtkCommunicator):
         return not self.acceptclose()
     
     def destroy_event(self):
-        # 'automagic' method for SIGNAL_BEFOREQUIT
+        # If we're the main window, this is the 'automagic' method for SIGNAL_BEFOREQUIT
         if self.app.mainwin == self:
             self.app.before_quit()
             gtk.main_quit()
@@ -155,3 +171,6 @@ class PGtkApplication(app.PApplicationBase, _PGtkCommunicator):
     
     def _eventloop(self):
         gtk.main()
+    
+    def process_events(self):
+        gtk.main_iteration(False)
