@@ -2,7 +2,7 @@
 """
 Module GTKBUTTON -- Python GTK Button Widgets
 Sub-Package GUI.TOOLKITS.GTK of Package PLIB -- Python GUI Toolkits
-Copyright (C) 2008 by Peter A. Donis
+Copyright (C) 2008-2009 by Peter A. Donis
 
 Released under the GNU General Public License, Version 2
 See the LICENSE and README files for more information
@@ -21,7 +21,8 @@ from _gtkcommon import _PGtkWidget, _gtkstockids
 class _PGtkButtonMixin(object):
     
     def set_caption(self, caption):
-        self.set_label(caption)
+        label = caption.replace("&", "_")
+        self.set_label(label)
     
     def set_icon(self, pxname):
         # No way currently to set custom icons in Gtk without major gymnastics
@@ -39,12 +40,14 @@ class PGtkButton(gtk.Button, _PGtkWidget, _PGtkButtonMixin, button.PButtonBase):
                 stockid = _gtkstockids[caption]
                 caption = None
         gtk.Button.__init__(self, None, stockid)
+        if caption is not None:
+            self.set_use_underline(True)
         _PGtkWidget.__init__(self, parent)
         button.PButtonBase.__init__(self, caption, pxname, target, geometry)
     
     def _font_widget(self):
         if self.get_use_stock():
-            return self.child.get_children()[1]
+            return self.child.get_children()[1] # FIXME: is this right?
         elif isinstance(self.child, gtk.Label):
             return self.child
         raise ValueError, "Gtk Button does not have a label."
