@@ -2,7 +2,7 @@
 """
 Module GTKCOMMON -- Python GTK Common Objects
 Sub-Package GUI.TOOLKITS.GTK of Package PLIB -- Python GUI Toolkits
-Copyright (C) 2008 by Peter A. Donis
+Copyright (C) 2008-2009 by Peter A. Donis
 
 Released under the GNU General Public License, Version 2
 See the LICENSE and README files for more information
@@ -32,8 +32,10 @@ _gtkstockids = {
     ACTION_REFRESH: gtk.STOCK_REFRESH,
     ACTION_ADD: gtk.STOCK_ADD,
     ACTION_REMOVE: gtk.STOCK_REMOVE,
+    ACTION_APPLY: gtk.STOCK_APPLY,
     ACTION_OK: gtk.STOCK_OK,
     ACTION_CANCEL: gtk.STOCK_CANCEL,
+    ACTION_PREFS: gtk.STOCK_PREFERENCES,
     ACTION_ABOUT: gtk.STOCK_ABOUT,
     ACTION_EXIT: gtk.STOCK_QUIT }
 
@@ -54,12 +56,16 @@ _gtksignals = {
     SIGNAL_CLICKED: "clicked",
     SIGNAL_TOGGLED: "toggled",
     SIGNAL_SELECTED: "selected",
+    SIGNAL_FOCUS_IN: "focus_in_event",
+    SIGNAL_FOCUS_OUT: "focus_out_event",
     SIGNAL_LISTVIEWCHANGED: "listview_changed",
     SIGNAL_TABLECHANGED: "table_changed",
     SIGNAL_TEXTCHANGED: "changed",
+    SIGNAL_EDITCHANGED: "changed",
     SIGNAL_ENTER: "enter_pressed",
     SIGNAL_TABCHANGED: "tab_changed",
     SIGNAL_WIDGETCHANGED: "changed",
+    SIGNAL_CLOSING: "window_closing",
     SIGNAL_HIDDEN: "destroy",
     SIGNAL_QUERYCLOSE: "delete_event",
     SIGNAL_BEFOREQUIT: "destroy" }
@@ -73,8 +79,11 @@ _gtksignals = {
 # (since the way we're set up it will always be the same as self anyway)
 
 _gtkwrappers = [SIGNAL_ACTIVATED, SIGNAL_CLICKED, SIGNAL_TOGGLED, SIGNAL_SELECTED,
-    SIGNAL_LISTVIEWCHANGED, SIGNAL_TABLECHANGED, SIGNAL_TEXTCHANGED, SIGNAL_ENTER, SIGNAL_TABCHANGED]
-_gtkplain = [SIGNAL_QUERYCLOSE, SIGNAL_HIDDEN, SIGNAL_BEFOREQUIT]
+    SIGNAL_LISTVIEWCHANGED, SIGNAL_TABLECHANGED,
+    SIGNAL_TEXTCHANGED, SIGNAL_EDITCHANGED, SIGNAL_ENTER,
+    SIGNAL_TABCHANGED]
+_gtkplain = [SIGNAL_FOCUS_IN, SIGNAL_FOCUS_OUT,
+    SIGNAL_QUERYCLOSE, SIGNAL_CLOSING, SIGNAL_HIDDEN, SIGNAL_BEFOREQUIT]
 
 def _gtk_wrapper(target, plain=False):
     if plain:
@@ -104,16 +113,20 @@ class _PGtkCommunicator(object):
     def do_notify(self, signal, *args):
         self.emit(_gtksignals[signal], *args)
 
-class _PGtkWidget(_PGtkCommunicator):
-    """ Mixin class with 'standard' GTK widget methods. """
+class _PGtkWidgetBase(object):
+    """ Mixin class to provide basic GTK widget methods. """
     
-    def __init__(self, parent, align=ALIGN_LEFT):
-        self._parent = parent
-        self._align = align
-        parent._add_widget(self)
+    def _widget(self):
+        return self
     
     def update(self):
-        self.queue_draw()
+        self._widget().queue_draw()
+    
+    def preferred_width(self):
+        return self._widget().get_size_request()[0]
+    
+    def preferred_height(self):
+        return self._widget().get_size_request()[1]
     
     def set_width(self, width):
         height = self.get_size_request()[1]
@@ -127,6 +140,9 @@ class _PGtkWidget(_PGtkCommunicator):
         if not (None in (left, top)):
             self._parent._move_widget(self, left, top)
     
+    def set_foreground_color(self, color):
+        pass # FIXME
+    
     def _font_info(self, font_name, font_size=None):
         #if font_name in _gtkfontfamilies:
         #    font_name = _gtkfontfamilies[font_name]
@@ -140,6 +156,12 @@ class _PGtkWidget(_PGtkCommunicator):
         # factored out
         return self
     
+    def get_font_name(self):
+        return self._font_widget().get_pango_context().get_font_description().get_family()
+    
+    def get_font_size(self):
+        return self._font_widget().get_pango_context().get_font_description().get_size()
+    
     def set_font(self, font_name, font_size=None):
         font_name, font_size = self._font_info(font_name, font_size)
         self._font_widget().modify_font(pango.FontDescription("%s %s" % (font_name, font_size)))
@@ -154,3 +176,18 @@ class _PGtkWidget(_PGtkCommunicator):
     
     def set_focus(self):
         self.grab_focus()
+
+class _PGtkWidget_(_PGtkCommunicator, _PGtkWidgetBase):
+    # Intermediate class so _PGtkClientWidget doesn't inherit the overridden __init__ method
+    pass
+
+class _PGtkWidget(_PGtkWidget_):
+    """ Mixin class for GTK widgets that can send/receive signals. """
+    
+    def __init__(self, parent, align=ALIGN_LEFT):
+        self._parent = parent
+        self._align = align
+        parent._add_widget(self)
+
+class _PGtkClientWidget(_PGtkWidget_):
+    """ Mixin class for GTK client widgets (i.e., can be used as client of main window). """
