@@ -2,7 +2,7 @@
 """
 Module GTKEDITCTRL -- Python GTK Editing Widgets
 Sub-Package GUI.TOOLKITS.GTK of Package PLIB -- Python GUI Toolkits
-Copyright (C) 2008 by Peter A. Donis
+Copyright (C) 2008-2009 by Peter A. Donis
 
 Released under the GNU General Public License, Version 2
 See the LICENSE and README files for more information
@@ -30,7 +30,7 @@ class _PGtkEditMixin(object):
     
     readonly = property(_get_readonly, _set_readonly)
 
-class PGtkEditBox(gtk.Entry, _PGtkWidget, editctrl.PEditControlBase, _PGtkEditMixin):
+class PGtkEditBox(gtk.Entry, _PGtkWidget, editctrl.PEditBoxBase, _PGtkEditMixin):
     
     # Need to define the 'enter' signal for Entry
     __gsignals__ = { _gtksignals[SIGNAL_ENTER]:
@@ -47,7 +47,7 @@ class PGtkEditBox(gtk.Entry, _PGtkWidget, editctrl.PEditControlBase, _PGtkEditMi
         _PGtkWidget.__init__(self, parent, align)
         # Connect to key pressed signal to catch Enter key
         self.connect("key_press_event", self.keypressed)
-        editctrl.PEditControlBase.__init__(self, target, geometry)
+        editctrl.PEditBoxBase.__init__(self, target, geometry)
     
     def keypressed(self, widget, event):
         if event.keyval == gtk.keysyms.Return:
@@ -70,12 +70,13 @@ class PGtkEditControl(gtk.ScrolledWindow, _PGtkWidget, editctrl.PEditControlBase
         (gobject.SIGNAL_RUN_LAST,
         gobject.TYPE_NONE, ()) }
     
+    _align = ALIGN_JUST # used by PGtkPanel to determine expand/fill
+    
     def __init__(self, parent, target=None, geometry=None, scrolling=False):
         gtk.ScrolledWindow.__init__(self)
         self.set_policy(gtk.POLICY_AUTOMATIC, gtk.POLICY_AUTOMATIC)
         self.set_shadow_type(gtk.SHADOW_IN)
         _PGtkWidget.__init__(self, parent, ALIGN_JUST)
-        editctrl.PEditControlBase.__init__(self, target, geometry)
         self._edit = gtk.TextView()
         if scrolling:
             self._edit.set_wrap_mode(gtk.WRAP_NONE)
@@ -83,6 +84,7 @@ class PGtkEditControl(gtk.ScrolledWindow, _PGtkWidget, editctrl.PEditControlBase
             self._edit.set_wrap_mode(gtk.WRAP_WORD)
         self._edit.get_buffer().connect("changed", self.textchanged)
         self.add(self._edit)
+        editctrl.PEditControlBase.__init__(self, target, geometry)
         self._edit.show()
     
     def _font_widget(self):
