@@ -2,7 +2,7 @@
 """
 Module GTKLABEL -- Python Gtk Text Label Widgets
 Sub-Package GUI.TOOLKITS.GTK of Package PLIB -- Python GUI Toolkits
-Copyright (C) 2008 by Peter A. Donis
+Copyright (C) 2008-2009 by Peter A. Donis
 
 Released under the GNU General Public License, Version 2
 See the LICENSE and README files for more information
@@ -18,10 +18,13 @@ from plib.gui._widgets import label
 
 from _gtkcommon import _PGtkWidget
 
-class PGtkTextLabel(gtk.Label, label.PTextLabelBase, _PGtkWidget):
+class PGtkTextLabel(gtk.Label, _PGtkWidget, label.PTextLabelBase):
     
-    def __init__(self, parent, text=None):
+    def __init__(self, parent, text=None, geometry=None):
         gtk.Label.__init__(self)
-        label.PTextLabelBase.__init__(self, text)
+        self.set_alignment(0, 0.5)
+        self.set_justify(gtk.JUSTIFY_LEFT)
+        _PGtkWidget.__init__(self, parent)
+        label.PTextLabelBase.__init__(self, text, geometry)
     
     # gtk.Label already has get_text and set_text methods
