@@ -2,7 +2,7 @@
 """
 Module GTKLISTVIEW -- Python GTK Tree/List View Objects
 Sub-Package GUI.TOOLKITS.GTK of Package PLIB -- Python GUI Toolkits
-Copyright (C) 2008 by Peter A. Donis
+Copyright (C) 2008-2009 by Peter A. Donis
 
 Released under the GNU General Public License, Version 2
 See the LICENSE and README files for more information
@@ -18,20 +18,15 @@ import gobject
 from plib.gui.defs import *
 from plib.gui._widgets import listview
 
-from _gtkcommon import _PGtkWidget, _gtkalignmap, _gtksignals
+from _gtkcommon import _PGtkClientWidget, _PGtkWidget, _gtkalignmap, _gtksignals
 
-class _PGtkListViewMixin(object):
+class PGtkListViewItem(listview.PListViewItemBase):
     
-    def _newitem(self, index, value):
-        if index == len(self):
+    def __init__(self, parent, index, data=None):
+        if index == len(parent):
             before = None
         else:
-            before = self._items[index]
-        return self.itemclass(self, index, value, before)
-
-class PGtkListViewItem(_PGtkListViewMixin, listview.PListViewItemBase):
-    
-    def __init__(self, parent, index, data=None, before=None):
+            before = parent._items[index]
         self._b = before # ugly hack since we have to postpone creating the gtk tree iter until _set_col below
         listview.PListViewItemBase.__init__(self, parent, index, data)
     
@@ -73,18 +68,20 @@ class PGtkListViewLabels(listview.PListViewLabelsBase):
             self._columns[index].set_title(label)
     
     def _set_width(self, index, width):
-        if width < 1:
-            width = self.defaultwidth
         #self._columns[index].set_min_width(width)
-        self._columns[index].set_fixed_width(width)
+        if width > 0:
+            # FIXME: the last column doesn't respect fixed sizing
+            self._columns[index].set_fixed_width(width)
+        # FIXME: implement auto-sizing if width is -1
     
     def _set_align(self, index, align):
+        # FIXME: wtf does this only align the header?
         self._columns[index].set_alignment(_gtkalignmap[align])
     
     def _set_readonly(self, index, readonly):
         pass
 
-class PGtkListView(gtk.TreeView, _PGtkWidget, _PGtkListViewMixin, listview.PListViewBase):
+class _PGtkListViewBase(gtk.TreeView):
     
     itemclass = PGtkListViewItem
     labelsclass = PGtkListViewLabels
@@ -94,17 +91,15 @@ class PGtkListView(gtk.TreeView, _PGtkWidget, _PGtkListViewMixin, listview.PList
         (gobject.SIGNAL_RUN_LAST,
         gobject.TYPE_NONE, (gobject.TYPE_PYOBJECT,)) }
     
-    def __init__(self, parent, labels=None, data=None, target=None):
-        args = tuple([gobject.TYPE_STRING for label in labels] + [gobject.TYPE_PYOBJECT])
+    def __init__(self, count):
+        args = [gobject.TYPE_PYOBJECT]
+        if count:
+            args = ([gobject.TYPE_STRING] * count) + args
+        args = tuple(args)
         self._model = gtk.TreeStore(*args)
         self._iter = None # easier logic for adding top level items
-        self._objcol = len(labels) # column that each item's Python self object reference will be stored in
+        self._objcol = count # column that each item's Python self object reference will be stored in
         gtk.TreeView.__init__(self, self._model)
-        _PGtkWidget.__init__(self, parent, ALIGN_JUST)
-        listview.PListViewBase.__init__(self, parent, labels, data, target)
-        
-        # The list view changed signal doesn't contain the current item, so gateway it
-        self.connect("cursor_changed", self.cursor_changed)
     
     def cursor_changed(self, obj):
         """ The list view selection cursor was changed. """
@@ -114,10 +109,6 @@ class PGtkListView(gtk.TreeView, _PGtkWidget, _PGtkListViewMixin, listview.PList
         """ Need to override gtk.TreeView's iter method. """
         return listview.PListViewBase.__iter__(self)
     
-    def __len__(self):
-        """ Need to override gtk.TreeView's len method. """
-        return listview.PListViewBase.__len__(self)
-    
     def _helperdel(self, index, item):
         self._model.remove(item._iter)
     
@@ -132,3 +123,41 @@ class PGtkListView(gtk.TreeView, _PGtkWidget, _PGtkListViewMixin, listview.PList
     
     def set_current_item(self, item):
         self.get_selection().select_iter(item._iter)
+
+class PGtkListView(_PGtkListViewBase, _PGtkClientWidget, listview.PListViewBase):
+    
+    _align = ALIGN_JUST # used by PGtkPanel to determine expand/fill
+    
+    def __init__(self, parent, labels=None, data=None, target=None):
+        if labels:
+            count = len(labels)
+        else:
+            count = 0
+        _PGtkListViewBase.__init__(self, count)
+        # no __init__ method for _PGtkClientWidget
+        listview.PListViewBase.__init__(self, parent, labels, data, target)
+        
+        # The list view changed signal doesn't contain the current item, so gateway it
+        self.connect("cursor_changed", self.cursor_changed)
+    
+    def __len__(self):
+        """ Need to override gtk.TreeView's len method. """
+        return listview.PListViewBase.__len__(self)
+
+class PGtkListBox(_PGtkListViewBase, _PGtkWidget, listview.PListBoxBase):
+    
+    def __init__(self, parent, labels=None, data=None, target=None, geometry=None):
+        if labels:
+            count = len(labels)
+        else:
+            count = 0
+        _PGtkListViewBase.__init__(self, count)
+        _PGtkWidget.__init__(self, parent, ALIGN_JUST) # FIXME: parent is set twice here and next line
+        listview.PListBoxBase.__init__(self, parent, labels, data, target, geometry)
+        
+        # The list view changed signal doesn't contain the current item, so gateway it
+        self.connect("cursor_changed", self.cursor_changed)
+    
+    def __len__(self):
+        """ Need to override gtk.TreeView's len method. """
+        return listview.PListBoxBase.__len__(self)
