@@ -2,7 +2,7 @@
 """
 Module GTKPANEL -- Python GTK Panel Objects
 Sub-Package GUI.TOOLKITS.GTK of Package PLIB -- Python GUI Toolkits
-Copyright (C) 2008 by Peter A. Donis
+Copyright (C) 2008-2009 by Peter A. Donis
 
 Released under the GNU General Public License, Version 2
 See the LICENSE and README files for more information
@@ -17,12 +17,14 @@ import gtk
 from plib.gui.defs import *
 from plib.gui._widgets import panel
 
+from _gtkcommon import _PGtkWidgetBase
+
 _gtklayouts = {
     LAYOUT_NONE: gtk.HBox,
     LAYOUT_HORIZONTAL: gtk.HBox,
     LAYOUT_VERTICAL: gtk.VBox }
 
-class PGtkPanel(panel.PPanelBase):
+class PGtkPanel(_PGtkWidgetBase, panel.PPanelBase):
     
     def __init__(self, parent, layout=LAYOUT_NONE, style=PANEL_NONE, align=ALIGN_JUST,
         margin=-1, spacing=-1, width=-1, height=-1):
@@ -34,6 +36,9 @@ class PGtkPanel(panel.PPanelBase):
         panel.PPanelBase.__init__(self, parent, layout, style, align,
             margin, spacing, width, height)
     
+    def _widget(self):
+        return self._box
+    
     def _add_widget(self, widget, x=0, y=0):
         #FIXME: find better general method for widget adds
         pass
@@ -66,6 +71,9 @@ class PGtkPanel(panel.PPanelBase):
     def set_min_size(self, width, height):
         self._box.set_size_request(width, height)
     
+    def set_box_width(self, width):
+        pass # FIXME
+    
     def set_margin(self, margin):
         self._box.set_border_width(margin)
     
