@@ -2,7 +2,7 @@
 """
 Module GTKTABLE -- Python GTK Table Objects
 Sub-Package GUI.TOOLKITS.GTK of Package PLIB -- Python GUI Toolkits
-Copyright (C) 2008 by Peter A. Donis
+Copyright (C) 2008-2009 by Peter A. Donis
 
 Released under the GNU General Public License, Version 2
 See the LICENSE and README files for more information
@@ -18,7 +18,7 @@ import gobject
 from plib.gui.defs import *
 from plib.gui._widgets import table
 
-from _gtkcommon import _PGtkCommunicator, _PGtkWidget, _gtkalignmap, _gtksignals
+from _gtkcommon import _PGtkClientWidget, _PGtkCommunicator, _gtkalignmap, _gtksignals
 
 table.gridlinesize += 2
 
@@ -77,7 +77,7 @@ class PGtkTableLabels(table.PTableLabelsBase):
     def _set_readonly(self, index, readonly):
         pass
 
-class PGtkTable(gtk.Table, _PGtkWidget, table.PTableBase):
+class PGtkTable(gtk.Table, _PGtkClientWidget, table.PTableBase):
     
     labelsclass = PGtkTableLabels
     
@@ -86,6 +86,8 @@ class PGtkTable(gtk.Table, _PGtkWidget, table.PTableBase):
         (gobject.SIGNAL_RUN_LAST,
         gobject.TYPE_NONE, (gobject.TYPE_INT, gobject.TYPE_INT)) }
     
+    _align = ALIGN_JUST # used by PGtkPanel to determine expand/fill
+    
     def __init__(self, parent, labels=None, data=None, target=None):
         """ Expects labels to be a list of PLabels. """
         
@@ -95,7 +97,6 @@ class PGtkTable(gtk.Table, _PGtkWidget, table.PTableBase):
         self.widgets = {}
         self.rowlabels = {}
         gtk.Table.__init__(self, self._r + 1, self._c + 1)
-        _PGtkWidget.__init__(self, parent, ALIGN_JUST)
         table.PTableBase.__init__(self, parent, labels, data, target)
     
     # We have to override gtk.Table's Python container methods since they
@@ -118,13 +119,13 @@ class PGtkTable(gtk.Table, _PGtkWidget, table.PTableBase):
         self.resize(self._r + 1, self._c + 1)
     
     def _get_cell(self, row, col):
-        if self.widgets.has_key((row, col)):
+        if (row, col) in self.widgets:
             return self.widgets[(row, col)]._w.get_text()
         else:
             return ""
     
     def _set_cell(self, row, col, value):
-        if not self.widgets.has_key((row, col)):
+        if (row, col) not in self.widgets:
             self.widgets[(row, col)] = PGtkTableFrame(PGtkTableEntry(self, row, col))
             self._attach_widget(row + 1, col + 1)
         self.widgets[(row, col)]._w.set_text(value)
@@ -154,7 +155,7 @@ class PGtkTable(gtk.Table, _PGtkWidget, table.PTableBase):
     def _remove_row(self, index):
         if self._r > 0:
             for col in range(self.colcount()):
-                if self.widgets.has_key((index, col)):
+                if (index, col) in self.widgets:
                     self.remove(self.widgets[(index, col)])
                     del self.widgets[(index, col)]
             self.remove(self.rowlabels[index])
@@ -172,7 +173,7 @@ class PGtkTable(gtk.Table, _PGtkWidget, table.PTableBase):
             return self._l[col].width + table.gridlinesize
     
     def set_text_fgcolor(self, row, col, color):
-        pass
+        pass # FIXME
     
     def set_cell_bkcolor(self, row, col, color):
-        pass
+        pass # FIXME
