@@ -2,7 +2,7 @@
 """
 Module KDEACTION -- Python KDE Action Objects
 Sub-Package GUI.TOOLKITS.KDE of Package PLIB -- Python GUI Toolkits
-Copyright (C) 2008 by Peter A. Donis
+Copyright (C) 2008-2009 by Peter A. Donis
 
 Released under the GNU General Public License, Version 2
 See the LICENSE and README files for more information
@@ -42,6 +42,14 @@ class PKDEToolBar(kdeui.KToolBar, action.PToolBarBase):
     def __init__(self, mainwidget):
         self._sep = False
         kdeui.KToolBar.__init__(self, mainwidget, "Main Toolbar")
+        # This has to be done here instead of in KMainWindow (unlike Qt)
+        # FIXME: How to do large icons in KDE?
+        #self.setFullSize(mainwidget.large_icons)
+        if mainwidget.show_labels:
+            it = kdeui.KToolBar.IconTextBottom
+        else:
+            it = kdeui.KToolBar.IconOnly
+        self.setIconText(it)
         action.PToolBarBase.__init__(self, mainwidget)
         #FIXME: Why is this necessary in KDE but not in Qt?
         mainwidget.addDockWindow(self)
