@@ -2,7 +2,7 @@
 """
 Module KDEAPP -- Python KDE Application Objects
 Sub-Package GUI.TOOLKITS.KDE of Package PLIB -- Python GUI Toolkits
-Copyright (C) 2008 by Peter A. Donis
+Copyright (C) 2008-2009 by Peter A. Donis
 
 Released under the GNU General Public License, Version 2
 See the LICENSE and README files for more information
@@ -31,7 +31,7 @@ def _kdeparse(aboutdata):
     data.setHomepage(aboutdata['website'])
     # FIXME: wtf doesn't this work? Alternately, why doesn't setting the program
     # icon elsewhere cause it to display here?
-    #data.setLogo(qt.QPixmap(aboutdata['icon']))
+    #data.setProgramLogo(qt.QPixmap(aboutdata['icon']))
     return data
 
 class _PKDEMainMixin(kdeui.KMainWindow, _PKDECommunicator):
@@ -39,6 +39,8 @@ class _PKDEMainMixin(kdeui.KMainWindow, _PKDECommunicator):
     Mixin class for KDE top windows and main windows.
     """
     
+    _closed = False # default for guard to trap close from system menu, see below
+    
     def _init_icon(self):
         if (self.aboutdata is not None) and ('icon' in self.aboutdata):
             self.setIcon(qt.QPixmap(self.aboutdata['icon']))
@@ -47,6 +49,12 @@ class _PKDEMainMixin(kdeui.KMainWindow, _PKDECommunicator):
         return self.width()
     w = property(_get_w)
     
+    def _show_window(self):
+        kdeui.KMainWindow.show(self)
+    
+    def _hide_window(self):
+        kdeui.KMainWindow.hide(self)
+    
     def set_caption(self, caption):
         self.setPlainCaption(caption)
     
@@ -65,8 +73,9 @@ class _PKDEMainMixin(kdeui.KMainWindow, _PKDECommunicator):
     
     def center(self):
         desktop = self.app.desktop()
-        self.move((desktop.width() - self.width())/2,
-            (desktop.height() - self.height())/2)
+        g = self.frameGeometry()
+        x, y = g.width(), g.height()
+        self.move((desktop.width() - x)/2, (desktop.height() - y)/2)
     
     def show_init(self):
         if hasattr(self, '_showMax'):
@@ -78,17 +87,23 @@ class _PKDEMainMixin(kdeui.KMainWindow, _PKDECommunicator):
     def about(self):
         if self.aboutdata is not None:
             kaboutdata = _kdeparse(self.aboutdata)
-            kdeui.KAboutApplication(kaboutdata).exec_loop()
+            dlg = kdeui.KAboutApplication(kaboutdata)
+            dlg # FIXME: wtf do we need this to prevent a segfault in the next line?
+            dlg.exec_loop()
+            #kdeui.KAboutApplication(kaboutdata).exec_loop()
     
     def exit(self):
-        self.close()
+        # Guard traps a close other than from this method, so we don't throw an
+        # exception if this method gets called after we close but before shutdown
+        # (?? Why isn't this necessary in Qt?)
+        if not self._closed:
+            self.close()
     
     def closeEvent(self, event):
         # 'automagic' code for SIGNAL_QUERYCLOSE
         if self.acceptclose():
-            # FIXME: either figure a way to emit this signal first, before acceptclose(),
-            # or change it to SIGNAL_BEFORECLOSE
-            #self._emit_event(SIGNAL_QUERYCLOSE)
+            self._emit_event(SIGNAL_CLOSING)
+            self._closed = True # set guard used above
             event.accept()
         else:
             event.ignore()
@@ -122,8 +137,14 @@ class PKDEApplication(kdecore.KApplication, app.PApplicationBase, _PKDECommunica
             klass = self.mainwidgetclass
         else:
             klass = cls
-        if klass.aboutdata is not None:
-            kaboutdata = _kdeparse(klass.aboutdata)
+        if hasattr(klass, 'aboutdata') and (klass.aboutdata is not None):
+            aboutdata = klass.aboutdata
+        elif hasattr(klass, 'clientwidgetclass') and hasattr(klass.clientwidgetclass, 'aboutdata'):
+            aboutdata = klass.clientwidgetclass.aboutdata
+        else:
+            aboutdata = None
+        if aboutdata is not None:
+            kaboutdata = _kdeparse(aboutdata)
         else:
             kaboutdata = kdecore.KAboutData('unnamed', 'unnamed', '0.0')
         kdecore.KCmdLineArgs.init(kaboutdata) # all the above because KDE requires this incantation first
@@ -137,3 +158,6 @@ class PKDEApplication(kdecore.KApplication, app.PApplicationBase, _PKDECommunica
     
     def _eventloop(self):
         self.exec_loop()
+    
+    def process_events(self):
+        self.processEvents()
