@@ -2,7 +2,7 @@
 """
 Module KDEBUTTON -- Python KDE Button Widgets
 Sub-Package GUI.TOOLKITS.KDE of Package PLIB -- Python GUI Toolkits
-Copyright (C) 2008 by Peter A. Donis
+Copyright (C) 2008-2009 by Peter A. Donis
 
 Released under the GNU General Public License, Version 2
 See the LICENSE and README files for more information
@@ -24,6 +24,8 @@ class _PKDEButtonMixin(object):
 
 class PKDEButton(kdeui.KPushButton, _PKDEWidget, _PKDEButtonMixin, button.PButtonBase):
     
+    widget_class = kdeui.KPushButton
+    
     def __init__(self, parent, caption=None, pxname=None, target=None, geometry=None):
         kdeui.KPushButton.__init__(self, parent)
         self.setSizePolicy(qt.QSizePolicy.Fixed, qt.QSizePolicy.Fixed)
@@ -39,6 +41,8 @@ class PKDEButton(kdeui.KPushButton, _PKDEWidget, _PKDEButtonMixin, button.PButto
 
 class PKDECheckBox(qt.QCheckBox, _PKDEWidget, _PKDEButtonMixin, button.PCheckBoxBase):
     
+    widget_class = qt.QCheckBox
+    
     def __init__(self, parent, caption=None, pxname=None, tristate=False, target=None, geometry=None):
         qt.QCheckBox.__init__(self, parent)
         self.setSizePolicy(qt.QSizePolicy.Fixed, qt.QSizePolicy.Fixed)
