@@ -2,7 +2,7 @@
 """
 Module KDEEDITCTRL -- Python KDE Editing Widgets
 Sub-Package GUI.TOOLKITS.KDE of Package PLIB -- Python GUI Toolkits
-Copyright (C) 2008 by Peter A. Donis
+Copyright (C) 2008-2009 by Peter A. Donis
 
 Released under the GNU General Public License, Version 2
 See the LICENSE and README files for more information
@@ -13,7 +13,7 @@ This module contains the KDE GUI objects for edit controls.
 import qt
 import kdeui
 
-from plib.gui.defs import *
+#from plib.gui.defs import *
 from plib.gui._widgets import editctrl
 
 from _kdecommon import _PKDEWidget
@@ -39,7 +39,9 @@ class _PKDEEditMixin(object):
     
     readonly = property(_get_readonly, _set_readonly)
 
-class PKDEEditBox(kdeui.KLineEdit, _PKDEWidget, editctrl.PEditControlBase, _PKDEEditMixin):
+class PKDEEditBox(kdeui.KLineEdit, _PKDEWidget, editctrl.PEditBoxBase, _PKDEEditMixin):
+    
+    widget_class = kdeui.KLineEdit
     
     def __init__(self, parent, target=None, geometry=None, expand=True):
         kdeui.KLineEdit.__init__(self, parent)
@@ -48,16 +50,20 @@ class PKDEEditBox(kdeui.KLineEdit, _PKDEWidget, editctrl.PEditControlBase, _PKDE
         else:
             self._horiz = qt.QSizePolicy.Fixed
         self.setSizePolicy(self._horiz, qt.QSizePolicy.Fixed)
-        editctrl.PEditControlBase.__init__(self, target, geometry)
+        editctrl.PEditBoxBase.__init__(self, target, geometry)
     
     def set_width(self, width):
         self.resize(width, self.height())
         # KDE line edits don't seem to fully respect qt.QSizePolicy.Fixed
         if self._horiz == qt.QSizePolicy.Fixed:
             self.setMaximumWidth(width)
+        elif self._horiz == qt.QSizePolicy.MinimumExpanding:
+            self.setMinimumWidth(width)
 
 class PKDEEditControl(kdeui.KTextEdit, _PKDEWidget, editctrl.PEditControlBase, _PKDEEditMixin):
     
+    widget_class = kdeui.KTextEdit
+    
     def __init__(self, parent, target=None, geometry=None, scrolling=False):
         kdeui.KTextEdit.__init__(self, parent)
         self.setTextFormat(qt.Qt.PlainText)
