@@ -2,7 +2,7 @@
 """
 Module KDEMAINWIN -- Python KDE Main Window Objects
 Sub-Package GUI.TOOLKITS.KDE of Package PLIB -- Python GUI Toolkits
-Copyright (C) 2008 by Peter A. Donis
+Copyright (C) 2008-2009 by Peter A. Donis
 
 Released under the GNU General Public License, Version 2
 See the LICENSE and README files for more information
@@ -65,8 +65,6 @@ class PKDEMainWindow(_PKDEMainMixin, mainwin.PMainWindowBase):
     
     def __init__(self, parent, cls=None):
         _PKDEMainMixin.__init__(self)
-        self.setUsesBigPixmaps(self.large_icons)
-        self.setUsesTextLabel(self.show_labels) # text still displays in tooltips
         mainwin.PMainWindowBase.__init__(self, parent, cls)
         self.setCentralWidget(self.clientwidget)
         if self.toolbar is not None:
