@@ -2,12 +2,12 @@
 """
 Module KDETABLE -- Python KDE Table Objects
 Sub-Package GUI.TOOLKITS.KDE of Package PLIB -- Python GUI Toolkits
-Copyright (C) 2008 by Peter A. Donis
+Copyright (C) 2008-2009 by Peter A. Donis
 
 Released under the GNU General Public License, Version 2
 See the LICENSE and README files for more information
 
-This module contains the GUI objects for the table widgets.
+This module contains the KDE GUI objects for the table widgets.
 """
 
 import qt
@@ -15,7 +15,7 @@ import qttable
 
 from plib.gui._widgets import table
 
-from _kdecommon import _PKDECommunicator, _kdecolormap
+from _kdecommon import _PKDEClientWidget, _kdecolormap
 
 class PKDETableLabels(table.PTableLabelsBase):
     
@@ -34,7 +34,9 @@ class PKDETableLabels(table.PTableLabelsBase):
     def _set_readonly(self, index, readonly):
         self.table.setColumnReadOnly(index, readonly)
 
-class PKDETable(qttable.QTable, table.PTableBase, _PKDECommunicator):
+class PKDETable(qttable.QTable, _PKDEClientWidget, table.PTableBase):
+    
+    widget_class = qttable.QTable
     
     labelsclass = PKDETableLabels
     
@@ -101,7 +103,7 @@ class PKDETable(qttable.QTable, table.PTableBase, _PKDECommunicator):
     
     def _set_color(self, mapping, row, col, color):
         if color is None:
-            if mapping.has_key((row, col)):
+            if (row, col) in mapping:
                 del mapping[(row, col)]
         else:
             mapping[(row, col)] = _kdecolormap[color]
@@ -128,9 +130,9 @@ class PKDETable(qttable.QTable, table.PTableBase, _PKDECommunicator):
         
         # FIXME: wtf isn't this already built into KDE???
         if colorgroup is not None:
-            if self.textcolors.has_key((row, col)):
+            if (row, col) in self.textcolors:
                 colorgroup.setColor(qt.QColorGroup.Text, self.textcolors[(row, col)])
-            if self.cellcolors.has_key((row, col)):
+            if (row, col) in self.cellcolors:
                 colorgroup.setColor(qt.QColorGroup.Base, self.cellcolors[(row, col)])
             qttable.QTable.paintCell(self, painter, row, col, rect, selected, colorgroup)
         else:
