@@ -2,7 +2,7 @@
 """
 Module QTAPP -- Python Qt Application Objects
 Sub-Package GUI.TOOLKITS.QT of Package PLIB -- Python GUI Toolkits
-Copyright (C) 2008 by Peter A. Donis
+Copyright (C) 2008-2009 by Peter A. Donis
 
 Released under the GNU General Public License, Version 2
 See the LICENSE and README files for more information
@@ -62,6 +62,12 @@ class _PQtMainMixin(qt.QMainWindow, _PQtCommunicator):
         return self.width()
     w = property(_get_w)
     
+    def _show_window(self):
+        qt.QMainWindow.show(self)
+    
+    def _hide_window(self):
+        qt.QMainWindow.hide(self)
+    
     def set_caption(self, caption):
         self.setCaption(caption)
     
@@ -80,8 +86,9 @@ class _PQtMainMixin(qt.QMainWindow, _PQtCommunicator):
     
     def center(self):
         desktop = self.app.desktop()
-        self.move((desktop.width() - self.width())/2,
-            (desktop.height() - self.height())/2)
+        g = self.frameGeometry()
+        x, y = g.width(), g.height()
+        self.move((desktop.width() - x)/2, (desktop.height() - y)/2)
     
     def show_init(self):
         if hasattr(self, '_showMax'):
@@ -96,9 +103,7 @@ class _PQtMainMixin(qt.QMainWindow, _PQtCommunicator):
     def closeEvent(self, event):
         # 'automagic' code for SIGNAL_QUERYCLOSE
         if self.acceptclose():
-            # FIXME: either figure a way to emit this signal first, before acceptclose(),
-            # or change it to SIGNAL_BEFORECLOSE
-            #self._emit_event(SIGNAL_QUERYCLOSE)
+            self._emit_event(SIGNAL_CLOSING)
             event.accept()
         else:
             event.ignore()
@@ -138,3 +143,6 @@ class PQtApplication(qt.QApplication, app.PApplicationBase, _PQtCommunicator):
     
     def _eventloop(self):
         self.exec_loop()
+    
+    def process_events(self):
+        self.processEvents()
