@@ -2,7 +2,7 @@
 """
 Module QTBUTTON -- Python Qt Button Widgets
 Sub-Package GUI.TOOLKITS.QT of Package PLIB -- Python GUI Toolkits
-Copyright (C) 2008 by Peter A. Donis
+Copyright (C) 2008-2009 by Peter A. Donis
 
 Released under the GNU General Public License, Version 2
 See the LICENSE and README files for more information
@@ -23,6 +23,8 @@ class _PQtButtonMixin(object):
 
 class PQtButton(qt.QPushButton, _PQtWidget, _PQtButtonMixin, button.PButtonBase):
     
+    widget_class = qt.QPushButton
+    
     def __init__(self, parent, caption=None, pxname=None, target=None, geometry=None):
         qt.QPushButton.__init__(self, parent)
         self.setSizePolicy(qt.QSizePolicy.Fixed, qt.QSizePolicy.Fixed)
@@ -38,6 +40,8 @@ class PQtButton(qt.QPushButton, _PQtWidget, _PQtButtonMixin, button.PButtonBase)
 
 class PQtCheckBox(qt.QCheckBox, _PQtWidget, _PQtButtonMixin, button.PCheckBoxBase):
     
+    widget_class = qt.QCheckBox
+    
     def __init__(self, parent, caption=None, pxname=None, tristate=False, target=None, geometry=None):
         qt.QCheckBox.__init__(self, parent)
         self.setSizePolicy(qt.QSizePolicy.Fixed, qt.QSizePolicy.Fixed)
