@@ -2,7 +2,7 @@
 """
 Module QTCOMMON -- Python Qt Common Objects
 Sub-Package GUI.TOOLKITS.QT of Package PLIB -- Python GUI Toolkits
-Copyright (C) 2008 by Peter A. Donis
+Copyright (C) 2008-2009 by Peter A. Donis
 
 Released under the GNU General Public License, Version 2
 See the LICENSE and README files for more information
@@ -20,13 +20,8 @@ _qtalignmap = {
     ALIGN_CENTER: qt.Qt.AlignCenter,
     ALIGN_RIGHT: qt.Qt.AlignRight }
 
-_qtcolormap = {
-    COLOR_BLACK: qt.QColor('black'),
-    COLOR_RED: qt.QColor('red'),
-    COLOR_BLUE: qt.QColor('blue'),
-    COLOR_GREEN: qt.QColor('green'),
-    COLOR_YELLOW: qt.QColor('yellow'),
-    COLOR_WHITE: qt.QColor('white') }
+_qtcolormap = dict((color, qt.QColor(color.lower()))
+    for color in COLORNAMES)
 
 _qtmessagefuncs = {
     MBOX_INFO: qt.QMessageBox.information,
@@ -42,13 +37,17 @@ _qtsignalmap = {
     SIGNAL_LISTVIEWCHANGED: "currentChanged(QListViewItem*)",
     SIGNAL_TABLECHANGED: "valueChanged(int, int)",
     SIGNAL_TEXTCHANGED: "textChanged()",
+    SIGNAL_EDITCHANGED: "textChanged(const QString&)",
     SIGNAL_ENTER: "returnPressed()",
     SIGNAL_TABCHANGED: "currentChanged(QWidget*)",
+    SIGNAL_NOTIFIER: "activated(int)",
     SIGNAL_BEFOREQUIT: "aboutToQuit()" }
 
 _qteventmap = {
-    SIGNAL_HIDDEN: "hideEvent" }#,
-    #SIGNAL_QUERYCLOSE: "closeEvent" }
+    SIGNAL_FOCUS_IN: "focusInEvent",
+    SIGNAL_FOCUS_OUT: "focusOutEvent",
+    SIGNAL_CLOSING: "closeEvent",
+    SIGNAL_HIDDEN: "hideEvent" }
 
 def _qtmap(signal):
     if signal in _qtsignalmap:
@@ -91,8 +90,14 @@ class _PQtCommunicator(object):
         if signal in self.enabled_events:
             self.do_notify(signal)
 
-class _PQtWidget(_PQtCommunicator):
-    """ Mixin class to provide some 'standard' Qt widget methods. """
+class _PQtWidgetBase(object):
+    """ Mixin class to provide minimal Qt widget methods. """
+    
+    def preferred_width(self):
+        return self.sizeHint().width()
+    
+    def preferred_height(self):
+        return self.sizeHint().height()
     
     def set_width(self, width):
         self.resize(width, self.height())
@@ -104,6 +109,15 @@ class _PQtWidget(_PQtCommunicator):
         if not (None in (left, top)):
             self.move(left, top)
     
+    def set_foreground_color(self, color):
+        self.setPaletteForegroundColor(_qtcolormap[color])
+    
+    def get_font_name(self):
+        return self.font().family()
+    
+    def get_font_size(self):
+        return self.font().pointSize()
+    
     def set_font(self, font_name, font_size=None):
         if font_size is None:
             font_size = default_font_size
@@ -119,3 +133,20 @@ class _PQtWidget(_PQtCommunicator):
     
     def set_focus(self):
         self.setFocus()
+
+class _PQtWidget(_PQtCommunicator, _PQtWidgetBase):
+    """ Mixin class for Qt widgets that can send/receive signals. """
+    
+    widget_class = None
+    
+    def focusInEvent(self, event):
+        self.widget_class.focusInEvent(self, event)
+        self._emit_event(SIGNAL_FOCUS_IN)
+    
+    def focusOutEvent(self, event):
+        self.widget_class.focusOutEvent(self, event)
+        self._emit_event(SIGNAL_FOCUS_OUT)
+
+class _PQtClientWidget(_PQtWidget):
+    """ Mixin class for Qt client widgets (i.e., can be used as client of main window). """
+    pass
