@@ -2,7 +2,7 @@
 """
 Module QTEDITCTRL -- Python Qt Editing Widgets
 Sub-Package GUI.TOOLKITS.QT of Package PLIB -- Python GUI Toolkits
-Copyright (C) 2008 by Peter A. Donis
+Copyright (C) 2008-2009 by Peter A. Donis
 
 Released under the GNU General Public License, Version 2
 See the LICENSE and README files for more information
@@ -34,7 +34,9 @@ class _PQtEditMixin(object):
     
     readonly = property(_get_readonly, _set_readonly)
 
-class PQtEditBox(qt.QLineEdit, _PQtWidget, editctrl.PEditControlBase, _PQtEditMixin):
+class PQtEditBox(qt.QLineEdit, _PQtWidget, editctrl.PEditBoxBase, _PQtEditMixin):
+    
+    widget_class = qt.QLineEdit
     
     def __init__(self, parent, target=None, geometry=None, expand=True):
         qt.QLineEdit.__init__(self, parent)
@@ -43,16 +45,20 @@ class PQtEditBox(qt.QLineEdit, _PQtWidget, editctrl.PEditControlBase, _PQtEditMi
         else:
             self._horiz = qt.QSizePolicy.Fixed
         self.setSizePolicy(self._horiz, qt.QSizePolicy.Fixed)
-        editctrl.PEditControlBase.__init__(self, target, geometry)
+        editctrl.PEditBoxBase.__init__(self, target, geometry)
     
     def set_width(self, width):
         self.resize(width, self.height())
         # Qt line edits don't seem to fully respect qt.QSizePolicy.Fixed
         if self._horiz == qt.QSizePolicy.Fixed:
             self.setMaximumWidth(width)
+        elif self._horiz == qt.QSizePolicy.MinimumExpanding:
+            self.setMinimumWidth(width)
 
 class PQtEditControl(qt.QTextEdit, _PQtWidget, editctrl.PEditControlBase, _PQtEditMixin):
     
+    widget_class = qt.QTextEdit
+    
     def __init__(self, parent, target=None, geometry=None, scrolling=False):
         qt.QTextEdit.__init__(self, parent)
         self.setTextFormat(qt.Qt.PlainText)
