@@ -2,7 +2,7 @@
 """
 Module QTLABEL -- Python Qt Text Label Widgets
 Sub-Package GUI.TOOLKITS.QT of Package PLIB -- Python GUI Toolkits
-Copyright (C) 2008 by Peter A. Donis
+Copyright (C) 2008-2009 by Peter A. Donis
 
 Released under the GNU General Public License, Version 2
 See the LICENSE and README files for more information
@@ -16,14 +16,21 @@ from plib.gui._widgets import label
 
 from _qtcommon import _PQtWidget
 
-class PQtTextLabel(qt.QLabel, label.PTextLabelBase, _PQtWidget):
+class PQtTextLabel(qt.QLabel, _PQtWidget, label.PTextLabelBase):
     
-    def __init__(self, parent, text=None):
+    widget_class = qt.QLabel
+    
+    def __init__(self, parent, text=None, geometry=None):
         qt.QLabel.__init__(self, parent)
-        label.PTextLabelBase.__init__(self, text)
+        label.PTextLabelBase.__init__(self, text, geometry)
     
     def get_text(self):
         return str(self.text())
     
     def set_text(self, value):
         self.setText(value)
+    
+    def set_width(self, width):
+        self.resize(width, self.height())
+        # Qt text labels don't seem to fully respect qt.QSizePolicy.MinimumExpanding
+        self.setMinimumWidth(width)
