@@ -2,12 +2,12 @@
 """
 Module QTPANEL -- Python Qt Panel Objects
 Sub-Package GUI.TOOLKITS.QT of Package PLIB -- Python GUI Toolkits
-Copyright (C) 2008 by Peter A. Donis
+Copyright (C) 2008-2009 by Peter A. Donis
 
 Released under the GNU General Public License, Version 2
 See the LICENSE and README files for more information
 
-This module contains the GUI objects for the panel widgets.
+This module contains the Qt GUI objects for the panel widgets.
 """
 
 import qt
@@ -16,6 +16,8 @@ from plib.gui.defs import *
 
 from plib.gui._widgets import panel
 
+from _qtcommon import _PQtWidgetBase
+
 _qtpanels = {
     PANEL_NONE: qt.QFrame.NoFrame | qt.QFrame.Plain,
     PANEL_BOX: qt.QFrame.Box | qt.QFrame.Plain,
@@ -30,7 +32,7 @@ def _qtsizepolicy(align):
         vert = qt.QSizePolicy.Fixed
     return horiz, vert
 
-class PQtPanel(qt.QHBox, panel.PPanelBase):
+class PQtPanel(qt.QHBox, _PQtWidgetBase, panel.PPanelBase):
     
     def __init__(self, parent, layout=LAYOUT_NONE, style=PANEL_NONE, align=ALIGN_JUST,
         margin=-1, spacing=-1, width=-1, height=-1):
@@ -45,6 +47,9 @@ class PQtPanel(qt.QHBox, panel.PPanelBase):
         if width > -1: self.setMinimumWidth(width)
         if height > -1: self.setMinimumHeight(height)
     
+    def set_box_width(self, width):
+        self.setLineWidth(width)
+    
     def set_margin(self, margin):
         self.setMargin(margin)
     
