@@ -2,7 +2,7 @@
 """
 Module WXAPP -- Python wxWidgets Application Objects
 Sub-Package GUI.TOOLKITS.WX of Package PLIB -- Python GUI Toolkits
-Copyright (C) 2008 by Peter A. Donis
+Copyright (C) 2008-2009 by Peter A. Donis
 
 Released under the GNU General Public License, Version 2
 See the LICENSE and README files for more information
@@ -61,6 +61,12 @@ class _PWxMainMixin(wx.Frame, _PWxCommunicator):
         return self.GetClientSizeTuple()[0]
     w = property(_get_w)
     
+    def _show_window(self):
+        wx.Frame.Show(self)
+    
+    def _hide_window(self):
+        wx.Frame.Hide(self)
+    
     def set_caption(self, caption):
         self.SetTitle(caption)
     
@@ -89,6 +95,10 @@ class _PWxMainMixin(wx.Frame, _PWxCommunicator):
         if event.CanVeto() and not self.acceptclose():
             event.Veto()
         else:
+            # Send the closing signal
+            self.do_notify(SIGNAL_CLOSING)
+            # Make sure the signal handlers are done before we destroy
+            self.ProcessPendingEvents()
             self.Destroy()
 
 class PWxTopWindow(_PWxMainMixin, app.PTopWindowBase):
@@ -130,3 +140,8 @@ class PWxApplication(wx.App, app.PApplicationBase, _PWxCommunicator):
     
     def _eventloop(self):
         self.MainLoop()
+    
+    def process_events(self):
+        #self.ProcessPendingEvents()
+        self.Yield()
+        #wx.SafeYield()
