@@ -2,7 +2,7 @@
 """
 Module WXEDITCTRL -- Python wxWidgets Editing Widgets
 Sub-Package GUI.TOOLKITS.WX of Package PLIB -- Python GUI Toolkits
-Copyright (C) 2008 by Peter A. Donis
+Copyright (C) 2008-2009 by Peter A. Donis
 
 Released under the GNU General Public License, Version 2
 See the LICENSE and README files for more information
@@ -17,11 +17,10 @@ from plib.gui._widgets import editctrl
 
 from _wxcommon import _PWxWidget
 
-class _PWxEditBase(wx.TextCtrl, _PWxWidget, editctrl.PEditControlBase):
+class _PWxEditBase(wx.TextCtrl, _PWxWidget):
     
-    def __init__(self, parent, target=None, geometry=None):
+    def __init__(self, parent):
         wx.TextCtrl.__init__(self, parent, style=self._style)
-        editctrl.PEditControlBase.__init__(self, target, geometry)
     
     def _get_text(self):
         return self.GetValue()
@@ -39,7 +38,7 @@ class _PWxEditBase(wx.TextCtrl, _PWxWidget, editctrl.PEditControlBase):
     
     readonly = property(_get_readonly, _set_readonly)
 
-class PWxEditBox(_PWxEditBase):
+class PWxEditBox(_PWxEditBase, editctrl.PEditBoxBase):
     
     _style = wx.TE_PROCESS_ENTER
     
@@ -49,9 +48,10 @@ class PWxEditBox(_PWxEditBase):
             self._align = ALIGN_JUST
         else:
             self._align = ALIGN_LEFT
-        _PWxEditBase.__init__(self, parent, target, geometry)
+        _PWxEditBase.__init__(self, parent)
+        editctrl.PEditBoxBase.__init__(self, target, geometry)
 
-class PWxEditControl(_PWxEditBase):
+class PWxEditControl(_PWxEditBase, editctrl.PEditControlBase):
     
     _style = wx.TE_MULTILINE | wx.TE_PROCESS_TAB
     
@@ -60,4 +60,5 @@ class PWxEditControl(_PWxEditBase):
         self._align = ALIGN_JUST
         if scrolling:
             self._style = self._style | wx.VSCROLL | wx.HSCROLL | wx.TE_DONTWRAP
-        _PWxEditBase.__init__(self, parent, target, geometry)
+        _PWxEditBase.__init__(self, parent)
+        editctrl.PEditControlBase.__init__(self, target, geometry)
