@@ -2,7 +2,7 @@
 """
 Module WXLABEL -- Python wxWidgets Text Label Widgets
 Sub-Package GUI.TOOLKITS.WX of Package PLIB -- Python GUI Toolkits
-Copyright (C) 2008 by Peter A. Donis
+Copyright (C) 2008-2009 by Peter A. Donis
 
 Released under the GNU General Public License, Version 2
 See the LICENSE and README files for more information
@@ -12,15 +12,17 @@ This module contains the wxWidgets GUI objects for text label widgets.
 
 import wx
 
+from plib.gui.defs import *
 from plib.gui._widgets import label
 
 from _wxcommon import _PWxWidget
 
-class PWxTextLabel(wx.StaticText, label.PTextLabelBase, _PWxWidget):
+class PWxTextLabel(wx.StaticText, _PWxWidget, label.PTextLabelBase):
     
-    def __init__(self, parent, text=None):
+    def __init__(self, parent, text=None, geometry=None):
         wx.StaticText.__init__(self, parent)
-        label.PTextLabelBase.__init__(self, text)
+        self._align = ALIGN_LEFT
+        label.PTextLabelBase.__init__(self, text, geometry)
     
     def get_text(self):
         return self.GetLabel()
