@@ -2,7 +2,7 @@
 """
 Module WXPANEL -- Python wxWidgets Panel Objects
 Sub-Package GUI.TOOLKITS.WX of Package PLIB -- Python GUI Toolkits
-Copyright (C) 2008 by Peter A. Donis
+Copyright (C) 2008-2009 by Peter A. Donis
 
 Released under the GNU General Public License, Version 2
 See the LICENSE and README files for more information
@@ -16,6 +16,9 @@ from plib.gui.defs import *
 
 from plib.gui._widgets import panel
 
+from _wxcommon import _PWxWidgetBase
+from _wxgroupbox import PWxGroupBox
+
 _wxstyles = {
     PANEL_NONE: wx.NO_BORDER,
     PANEL_BOX: wx.SIMPLE_BORDER,
@@ -33,7 +36,7 @@ _wxflags = {
     ALIGN_TOP: wx.ALIGN_TOP,
     ALIGN_BOTTOM: wx.ALIGN_BOTTOM }
 
-class PWxPanel(wx.Panel, panel.PPanelBase):
+class PWxPanel(wx.Panel, _PWxWidgetBase, panel.PPanelBase):
     
     def __init__(self, parent, layout=LAYOUT_NONE, style=PANEL_NONE, align=ALIGN_JUST,
         margin=-1, spacing=-1, width=-1, height=-1):
@@ -49,6 +52,7 @@ class PWxPanel(wx.Panel, panel.PPanelBase):
     def _addwidget(self, widget):
         # People say that the wxWidgets layout model is simple and easy to use,
         # but comparing this cruft with the Qt or KDE code, I'm not so sure...
+        
         if self._haswidgets:
             if self._spacing > -1:
                 self._sizer.AddSpacer(self._spacing)
@@ -101,6 +105,9 @@ class PWxPanel(wx.Panel, panel.PPanelBase):
             height = curr_h
         self._sizer.SetMinSize((width, height))
     
+    def set_box_width(self, width):
+        pass # FIXME
+    
     def set_margin(self, margin):
         # Margin is dealt with differently in wxWidgets, see above
         pass
