@@ -2,7 +2,7 @@
 """
 Module WXTABLE -- Python wxWidgets Table Objects
 Sub-Package GUI.TOOLKITS.WX of Package PLIB -- Python GUI Toolkits
-Copyright (C) 2008 by Peter A. Donis
+Copyright (C) 2008-2009 by Peter A. Donis
 
 Released under the GNU General Public License, Version 2
 See the LICENSE and README files for more information
@@ -15,7 +15,7 @@ import wx.grid
 from plib.gui.defs import *
 from plib.gui._widgets import table
 
-from _wxcommon import _PWxCommunicator, _wxalignmap
+from _wxcommon import _PWxClientWidget, _wxalignmap
 
 class PWxTableLabels(table.PTableLabelsBase):
     
@@ -35,7 +35,7 @@ class PWxTableLabels(table.PTableLabelsBase):
         #self.SetCellReadOnly(row, index, label.readonly)
         pass
 
-class PWxTable(wx.grid.Grid, table.PTableBase, _PWxCommunicator):
+class PWxTable(wx.grid.Grid, _PWxClientWidget, table.PTableBase):
     
     labelsclass = PWxTableLabels
     
