@@ -2,7 +2,7 @@
 """
 Module WXTABWIDGET -- Python wxWidgets Tab Widget
 Sub-Package GUI.TOOLKITS.QT of Package PLIB -- Python GUI Toolkits
-Copyright (C) 2008 by Peter A. Donis
+Copyright (C) 2008-2009 by Peter A. Donis
 
 Released under the GNU General Public License, Version 2
 See the LICENSE and README files for more information
@@ -15,9 +15,9 @@ import wx
 from plib.gui.defs import *
 from plib.gui._widgets import tabwidget
 
-from _wxcommon import _PWxCommunicator
+from _wxcommon import _PWxClientWidget
 
-class PWxTabWidget(wx.Notebook, tabwidget.PTabWidgetBase, _PWxCommunicator):
+class PWxTabWidget(wx.Notebook, _PWxClientWidget, tabwidget.PTabWidgetBase):
     
     def __init__(self, parent, tabs=None, target=None):
         wx.Notebook.__init__(self, parent)
