@@ -2,13 +2,25 @@
 """
 Module HELPERS -- GUI Widget Helper Classes
 Sub-Package GUI.WIDGETS of Package PLIB -- Python GUI Framework
-Copyright (C) 2008 by Peter A. Donis
+Copyright (C) 2008-2009 by Peter A. Donis
 
 Released under the GNU General Public License, Version 2
 See the LICENSE and README files for more information
 
-Defines "helper" classes that implement basic functionality used
-by various widgets.
+Defines "helper" classes that implement the basic functionality
+to make widgets look like Python containers. The two basic
+container structures supported are:
+
+- A "row" structure: the top-level container is a sequence of rows,
+  and each row is in turn a sequence of columns. The top-level
+  container is fully mutable (new rows can be inserted/appended,
+  and existing rows can be deleted), but each row is of fixed length
+  (columns cannot be added or deleted).
+
+- A "tree" structure: the top-level container is a mutable list of items,
+  where each item is a 2-sequence: the first member is a fixed-length
+  sequence of columns, and the second member is a list of sub-items,
+  which has the same structure recursively.
 """
 
 from plib.stdlib import abstractlist, basesequence, normalize, SortMixin
@@ -117,10 +129,9 @@ class _PShift(object):
             for i in range(n, index, -1):
                 self._items[i] = self._items[i - 1]
             
-            # List will be longer by one when insert/append occurs
-            # in _add method below (so this statement isn't really
-            # needed, it's there for symmetry with _shiftleft)
-            del self._items[index]
+            # This isn't strictly necessary but it's neater (the item at
+            # index will be re-set in a moment anyway)
+            self._items[index] = None
     
     def _shiftleft(self, index):
         """ Move items above index in the list 'down' one index (to be
@@ -135,8 +146,6 @@ class _PShift(object):
                 self._items[i] = self._items[i + 1]
             
             # Shorten the list by one (item at n is stored at n - 1)
-            # (note that unlike the del in _shiftright above, this
-            # statement really is necessary to shorten the list)
             del self._items[n]
 
 class _PHelper(_PShift, SortMixin, abstractlist):
@@ -155,7 +164,7 @@ class _PHelper(_PShift, SortMixin, abstractlist):
     side effects desired (such as adding/deleting items from a list
     view or rows from a table).
     
-    Note also that all of the sequence emulation methods work with the
+    Note also that most of the sequence emulation methods work with the
     actual 'values', not the helper items. To access the helper items,
     use the items attribute (which is a standard dict mapping index
     values to the helper items).
@@ -236,6 +245,10 @@ class _PHelper(_PShift, SortMixin, abstractlist):
         self._helperdel(index, item)
         self._shiftleft(index)
     
+    # Note: we subclass abstractlist instead of baselist because we don't
+    # want to support slicing except indirectly, by using it to insert/append;
+    # thus we filter index type more tightly than baselist does.
+    
     def __getitem__(self, index):
         if isinstance(index, int):
             return self._get(normalize(self.__len__(), index))
@@ -320,7 +333,10 @@ class _PTreeHelper(_PHelper):
         raise NotImplementedError
     
     def current_index(self):
-        return self.index(self.current_item())
+        item = self.current_item()
+        if item is not None:
+            return self.index(self.current_item())
+        return None
     
     def set_current_index(self, index):
         self.set_current_item(self._items[index])
