@@ -2,7 +2,7 @@
 """
 Module LABEL -- GUI Text Label Widgets
 Sub-Package GUI.WIDGETS of Package PLIB -- Python GUI Framework
-Copyright (C) 2008 by Peter A. Donis
+Copyright (C) 2008-2009 by Peter A. Donis
 
 Released under the GNU General Public License, Version 2
 See the LICENSE and README files for more information
@@ -10,12 +10,15 @@ See the LICENSE and README files for more information
 Defines the widget classes for text label widgets.
 """
 
-class PTextLabelBase(object):
+from plib.gui._widgets import _control
+
+class PTextLabelBase(_control._PDialogControl):
     """
-    Base class for a widget that just displays text.
+    Base class for a widget that just displays a single line of text.
     """
     
-    def __init__(self, text=None):
+    def __init__(self, text=None, geometry=None):
+        _control._PDialogControl.__init__(self, None, geometry)
         if text is not None:
             self.set_text(text)
     
