@@ -2,7 +2,7 @@
 """
 Module LISTVIEW -- GUI Tree/List View Widgets
 Sub-Package GUI.WIDGETS of Package PLIB -- Python GUI Framework
-Copyright (C) 2008 by Peter A. Donis
+Copyright (C) 2008-2009 by Peter A. Donis
 
 Released under the GNU General Public License, Version 2
 See the LICENSE and README files for more information
@@ -10,9 +10,10 @@ See the LICENSE and README files for more information
 Defines the widget classes for tree view/list view widgets.
 """
 
+import sys
+
 from plib.gui.defs import *
-from plib.gui._widgets import _helpers
-from plib.gui._widgets import _signal
+from plib.gui._widgets import _control, _helpers, _signal
 
 class PListViewItemCols(_helpers._PTreeHelperItemCols):
     """ Exposes columns of a list view item as a sequence. """
@@ -39,6 +40,7 @@ class PListViewItemBase(_helpers._PTreeHelperItem):
     colsclass = PListViewItemCols
     
     def __init__(self, parent, index, data=None):
+        self._parent = parent
         self._listview = self._listview_from_parent(parent)
         _helpers._PTreeHelperItem.__init__(self, parent, index, data)
     
@@ -69,27 +71,66 @@ class PListViewItemBase(_helpers._PTreeHelperItem):
 
 class PListViewLabelsBase(_helpers._PHelperColLabels):
     
-    defaultwidth = 800
-    
     def _get_listview(self):
         return self._helper
     
     listview = property(_get_listview)
 
-class PListViewBase(_signal._PNotifyControl, _helpers._PTreeHelper):
+class PListViewMixin(_helpers._PTreeHelper):
     """
-    List view that looks like a list of child list view items.
+    Mixin class for PListViewBase and PListBoxBase, to implement
+    common behaviors.
     """
     
     signal = SIGNAL_LISTVIEWCHANGED
     
-    def __init__(self, parent, labels=None, data=None, target=None):
+    def __init__(self, parent, labels=None, data=None):
         self._parent = parent
         if not hasattr(self.itemclass, 'listviewclass'):
             self.itemclass.listviewclass = self.__class__
-        _signal._PNotifyControl.__init__(self, target)
         _helpers._PTreeHelper.__init__(self, labels, data)
     
     def colcount(self):
         """ Placeholder for derived classes to implement. """
         raise NotImplementedError
+
+class PListViewBase(PListViewMixin, _signal._PNotifyControl):
+    """
+    List view that looks like a list of child list view items.
+    """
+    
+    def __init__(self, parent, labels=None, data=None, target=None):
+        PListViewMixin.__init__(self, parent, labels, data)
+        _signal._PNotifyControl.__init__(self, target)
+
+class PListBoxBase(PListViewMixin, _control._PDialogControl):
+    """
+    List view specialized for use as a dialog control. Includes
+    convenience methods to handle common special cases.
+    """
+    
+    def __init__(self, parent, labels=None, data=None, target=None, geometry=None):
+        PListViewMixin.__init__(self, parent, labels, data)
+        _control._PDialogControl.__init__(self, target, geometry)
+    
+    if sys.version_info < (2, 4):
+        
+        def extend_flat(self, items):
+            """ Adds list of items to list box; assumes no children, but multiple columns. """
+            for item in items:
+                self.append((item, []))
+        
+        def extend_list(self, items):
+            """ Adds list of items to list box; assumes a single column list box with no children. """
+            for item in items:
+                self.append(([item], []))
+    
+    else:
+        
+        def extend_flat(self, items):
+            """ Adds list of items to list box; assumes no children, but multiple columns. """
+            self.extend((item, []) for item in items)
+        
+        def extend_list(self, items):
+            """ Adds list of items to list box; assumes a single column list box with no children. """
+            self.extend(([item], []) for item in items)
