@@ -2,7 +2,7 @@
 """
 Module TABLE -- GUI Table Widgets
 Sub-Package GUI.WIDGETS of Package PLIB -- Python GUI Framework
-Copyright (C) 2008 by Peter A. Donis
+Copyright (C) 2008-2009 by Peter A. Donis
 
 Released under the GNU General Public License, Version 2
 See the LICENSE and README files for more information
@@ -10,6 +10,8 @@ See the LICENSE and README files for more information
 Defines the widget classes for table widgets.
 """
 
+import sys
+
 from plib.gui.defs import *
 from plib.gui._widgets import _helpers
 from plib.gui._widgets import _signal
@@ -125,13 +127,25 @@ class PTableBase(_signal._PNotifyControl, _helpers._PRowHelper):
     def colwidth(self, col):
         return self.defaultcolwidth
     
-    def minwidth(self):
-        return sum([self.colwidth(col) for col in range(self.colcount())]) + \
-            self.leftmargin() + scrollbarsize + (self.colcount() * gridlinesize)
+    if sys.version_info < (2, 4):
+        
+        def minwidth(self):
+            return sum([self.colwidth(col) for col in xrange(self.colcount())]) + \
+                self.leftmargin() + scrollbarsize + (self.colcount() * gridlinesize)
+        
+        def minheight(self):
+            return sum([self.rowheight(row) for row in xrange(self.rowcount())]) + \
+                self.topmargin() + scrollbarsize + (self.rowcount() * gridlinesize)
     
-    def minheight(self):
-        return sum([self.rowheight(row) for row in range(self.rowcount())]) + \
-            self.topmargin() + scrollbarsize + (self.rowcount() * gridlinesize)
+    else:
+        
+        def minwidth(self):
+            return sum(self.colwidth(col) for col in xrange(self.colcount())) + \
+                self.leftmargin() + scrollbarsize + (self.colcount() * gridlinesize)
+        
+        def minheight(self):
+            return sum(self.rowheight(row) for row in xrange(self.rowcount())) + \
+                self.topmargin() + scrollbarsize + (self.rowcount() * gridlinesize)
     
     def force_repaint(self):
         """ Placeholder for derived classes to implement. """
