@@ -2,7 +2,7 @@
 """
 Module TABWIDGET -- GUI Tab Widget
 Sub-Package GUI.WIDGETS of Package PLIB -- Python GUI Framework
-Copyright (C) 2008 by Peter A. Donis
+Copyright (C) 2008-2009 by Peter A. Donis
 
 Released under the GNU General Public License, Version 2
 See the LICENSE and README files for more information
@@ -27,7 +27,16 @@ class PTabWidgetBase(_signal._PNotifyControl, _helpers._PShift, baselist):
         self._parent = parent
         _signal._PNotifyControl.__init__(self, target)
         _helpers._PShift.__init__(self)
-        baselist.__init__(self, tabs)
+        baselist.__init__(self)
+        if tabs is not None:
+            self._createtabs(tabs)
+    
+    def _createtabs(self, tabs):
+        """
+        Create tabs from sequence; assumes that the sequence
+        contains tuples of (title, widget) for each tab.
+        """
+        self.extend(tabs)
     
     def _get_tabtitle(self, index):
         """ Placeholder for derived classes to implement. """
