@@ -1,7 +1,7 @@
 #! /usr/bin/env python
 """
 Sub-Package INI of Package PLIB -- Python INI Objects
-Copyright (C) 2008 by Peter A. Donis
+Copyright (C) 2008-2009 by Peter A. Donis
 
 Released under the GNU General Public License, Version 2
 See the LICENSE and README files for more information
@@ -54,11 +54,7 @@ app closes or when the user selects "Save Preferences" or suchlike.
 
 import os
 
-# Flags for the data types
-
-INI_INTEGER = 0
-INI_BOOLEAN = 1
-INI_STRING = 2
+from defs import *
 
 # Only OS's currently comprehended are POSIX and NT
 
@@ -92,6 +88,9 @@ class PIniInterface(object):
     other classes see a single consistent API.
     """
     
+    falsestr = 'no'
+    truestr = 'yes'
+    
     def __init__(self):
         object.__init__(self)
         if os.name == "posix":
@@ -189,6 +188,12 @@ class PIniInterface(object):
     
     def writevalue(self, oname, vtype, avalue):
         if self.parser is not None:
+            # Dunno why ConfigParser doesn't have setint, setboolean corresponding
+            # to getint, getboolean above, but oh well...
+            if vtype == INI_BOOLEAN:
+                avalue = {False: self.falsestr, True: self.truestr}[avalue]
+            else:
+                avalue = str(avalue)
             self.parser.set(self.opensname, oname, avalue)
         
         elif self.openkey is not None:
@@ -253,13 +258,13 @@ class PIniFileSection(object):
     
     def read(self, intf):
         intf.opensection(self.sectname)
-        for oname in self.options.keys():
+        for oname in self.options.iterkeys():
             self.options[oname].read(intf)
         intf.closesection(self.sectname)
     
     def write(self, intf):
         intf.opensection(self.sectname)
-        for oname in self.options.keys():
+        for oname in self.options.iterkeys():
             self.options[oname].write(intf)
         intf.closesection(self.sectname)
 
@@ -308,13 +313,13 @@ class PIniFileBase(object):
     
     def readvalues(self):
         self.intf.initialize(self.ininame)
-        for sname in self.sections.keys():
+        for sname in self.sections.iterkeys():
             self.sections[sname].read(self.intf)
         self.intf.shutdown(self.ininame)
     
     def writevalues(self):
         self.intf.initialize(self.ininame)
-        for sname in self.sections.keys():
+        for sname in self.sections.iterkeys():
             self.sections[sname].write(self.intf)
         self.intf.shutdown(self.ininame, True)
 
@@ -371,7 +376,7 @@ class PIniFile(PIniFileBase):
     def readini(self):
         """ Called to read preferences from file and feed them to the program. """
         self.readvalues()
-        for key in self.vardict.keys():
+        for key in self.vardict.iterkeys():
             entry = self.vardict[key]
             value = self.getvalue(key[0], key[1])
             if isinstance(entry, tuple):
@@ -381,7 +386,7 @@ class PIniFile(PIniFileBase):
     
     def writeini(self):
         """ Called to feed preferences data from the program and write to file. """
-        for key in self.vardict.keys():
+        for key in self.vardict.iterkeys():
             entry = self.vardict[key]
             if isinstance(entry, tuple):
                 value = entry[0]()
