@@ -1,18 +1,18 @@
 #!/usr/bin/env python
 """
 Sub-Package STDLIB of Package PLIB -- Python Standard Library Extensions
-Copyright (C) 2008 by Peter A. Donis
+Copyright (C) 2008-2009 by Peter A. Donis
 
 Released under the GNU General Public License, Version 2
 See the LICENSE and README files for more information
 
 This sub-package contains classes and functions which extend or
-modify the standard Python library, and which may be candidates
-for inclusion in future versions of the library.
+modify the Python standard library.
 
-Note that the ModuleProxy class from the CLASSES sub-package of PLIB
-is used to put the sub-modules of this package in the package
-namespace, so that you can write, for example,
+Note that, as with the PLIB.CLASSES sub-package, the ModuleProxy
+class from the PLIB.UTILS sub-package is used to put the sub-modules
+of this package in the package namespace, so that you can write,
+for example,
 
     from plib.stdlib import abstractcontainer
 
@@ -20,16 +20,36 @@ instead of having to write
 
     from plib.stdlib.abstractcontainer import abstractcontainer
 
-See the CLASSES sub-package docstring and comments for more details.
+See the PLIB.CLASSES sub-package docstring and comments for more details.
 
 This file itself currently includes:
 
-variables pythonpath, sitepath, plibpath -- contain pathnames to
-    root python directory, site-packages directory, and plib directory
+variables pythonpath, plibpath, binpath, sharepath --
+    contain pathnames to root python directory, plib directory,
+    third-party binary directory, and third-party shared data directory
+    (the latter two are where plib's scripts and example programs will
+    have been installed)
 
 functions any, all -- a little different from the functions built in
     to Python 2.5, these allow an optional predicate
 
+function closure -- similar to functools.partial from Python 2.5; returns
+    a callable object that returns the same result as calling the passed
+    function with the passed arguments (but does not allow additional
+    arguments with the actual call, as functools.partial does)
+
+function dotted_import -- wraps the __import__ builtin so that it
+    returns the 'innermost' module in a dotted name; the equivalent
+    of 'import x.y.z'
+
+function dotted_from_import -- dotted_import, plus a getattr call to
+    retrieve the named attribute from the dotted module; the equivalent
+    of 'from x.y.z import a' (except that module a of package x.y.z
+    will not be returned unless it has already been imported into the
+    namespace of x.y.z)
+
+function first -- returns first item in iterable, or default if empty.
+
 function inrange -- returns index forced to be >= low, <= high.
 
 function inverted -- returns the inverse of a mapping.
@@ -48,9 +68,23 @@ fixes it. Note that the issue can also arise, as the blog entry notes,
 with line-oriented network protocols, which means any time you are
 using a "file-like object" derived from a socket.
 
+function last -- returns last item in iterable, or default if empty.
+
 function normalize -- returns index with negative values normalized
     relative to count.
 
+function normalize_slice -- returns a list of indexes "covered" by a
+    slice (normalized relative to count), or an integer giving the
+    index to which a zero-length slice refers (normalized relative
+    to count).
+
+function slice_len -- returns the "length" of a slice (meaning the
+    number of indexes that would be affected if it were used as an
+    index into a sequence).
+
+function sorted -- backports the builtin to Python versions < 2.4. No
+    reverse functionality for earlier versions.
+
 functions strtobool, strtodate -- self-explanatory.
 
 function cached_property (and auxiliary class CachedProperty) --
@@ -91,51 +125,61 @@ import sys
 import os
 import datetime
 import glob
+from itertools import ifilter, ifilterfalse
 
-from plib.classes import ModuleProxy
+from plib.utils import ModuleProxy
 
-if sys.platform == 'win32':
-    pythonpath = os.path.join(sys.prefix, "Lib")
-else:
-    pythonpath = os.path.join(sys.prefix, "lib", "python" + sys.version[:3])
-    if not os.path.exists(pythonpath):
-        pythonpath = pythonpath[:-3]
-if not os.path.exists(pythonpath):
-    raise OSError, "python directory not found!"
-
-sitepath = os.path.join(pythonpath, 'site-packages')
-if not os.path.exists(sitepath):
-    raise OSError, "site-packages directory not found!"
-
-plibpath = os.path.join(sitepath, "plib")
-if not os.path.exists(plibpath):
-    for p in sys.path:
-        p = os.path.join(p, "plib")
-        if os.path.exists(p):
-            plibpath = p
-            break
-    if not os.path.exists(plibpath):
-        raise OSError, "plib directory not found!"
+from _paths import *
+from SortMixin import SortMixin
 
 def any(iterable, predicate=bool):
     """ Return True if any element of iterable satisfies predicate. """
-    for element in iterable:
-        if predicate(element):
-            return True
+    for element in ifilter(predicate, iterable):
+        return True
     return False
 
 def all(iterable, predicate=bool):
     """ Return True only if all elements of iterable satisfy predicate. """
-    for element in iterable:
-        if not predicate(element):
-            return False
+    for element in ifilterfalse(predicate, iterable):
+        return False
     return True
 
-def inrange(index, low, high):
-    """ Force index to be within the range low to high. """
+def closure(fn, *args, **kwargs):
+    """ Return a no-parameter callable equivalent to fn(*args, **kwargs). """
+    def f():
+        return fn(*args, **kwargs)
+    return f
+
+def dotted_import(name):
+    """ Returns the module pointed to by import x.y.z. """
+    mod = __import__(name)
+    components = name.split('.')
+    for comp in components[1:]:
+        mod = getattr(mod, comp)
+    return mod
+
+def dotted_from_import(modname, attrname):
+    """ Returns the module attribute pointed to by from x.y.z import a. """
+    return getattr(dotted_import(modname), attrname)
+
+def first(iterable, default=None):
+    """ Return first item in iterable, or default if empty. """
+    for item in iterable:
+        return item
+    return default
+
+def inrange(index, v1, v2):
+    """ Force index to be within the range v1 to v2, and return result. """
+    if v1 < v2:
+        low = v1
+        high = v2
+    else:
+        low = v2
+        high = v1
     return min(max(index, low), high)
 
 if sys.version_info < (2, 4):
+    
     def inverted(mapping, keylist=None):
         """
         Return a dict that is the inverse of the given mapping. The
@@ -160,6 +204,7 @@ if sys.version_info < (2, 4):
         return result
 
 else:
+    
     def inverted(mapping, keylist=None):
         """
         Return a dict that is the inverse of the given mapping. The
@@ -189,6 +234,13 @@ def iterfile(f):
             return # we've reached EOF
         yield line
 
+def last(iterable, default=None):
+    """ Return last item in iterable, or default if empty. """
+    result = default
+    for item in iterable:
+        result = item
+    return result
+
 def normalize(count, index):
     """
     Return index value with negative indexes converted to indexes
@@ -201,7 +253,7 @@ def normalize(count, index):
     else:
         result = index
     if (result < 0) or (result > count - 1):
-        raise IndexError, "List index out of range."
+        raise IndexError, "sequence index out of range"
     return result
 
 def normalize_slice(count, index):
@@ -214,7 +266,14 @@ def normalize_slice(count, index):
     -- For an empty slice (e.g., [x:x]), return the slice location (x)
        as an int.
     
-    Note that, unlike normalize above, this function will never throw an
+    -- For extended slices, if start and stop are the same, return an
+       empty list; otherwise treat as a non-empty slice.
+    
+    The index(es) returned will be normalized relative to count, and indexes
+    out of range after normalization will be truncated to range(0, count + 1).
+    The extra index at count is to allow for the possibility of an append
+    (a zero-length slice with index == count). Note that this means that,
+    unlike the normalize function above, this function will never throw an
     exception due to values being out of range; this is consistent with the
     observed semantics of Python slice syntax, where even values way out of
     range are accepted and truncated to zero or the end of the sequence.
@@ -222,35 +281,106 @@ def normalize_slice(count, index):
     slice step.
     """
     
-    if index.start is None:
-        start = 0
-    else:
-        start = int(index.start)
-        if start < 0:
-            start += count
-        start = inrange(start, 0, count)
-    if index.stop is None:
-        stop = count
-    else:
-        stop = int(index.stop)
-        if stop < 0:
-            stop += count
-        stop = inrange(stop, 0, count)
     if index.step is None:
         step = 1
     else:
         step = int(index.step)
     if step == 0:
         raise ValueError, "Slice step cannot be zero."
-    if start == stop:
-        return start
+    if index.start is None:
+        if step < 0:
+            start = count - 1
+        else:
+            start = 0
     else:
+        start = int(index.start)
+        if start < 0:
+            start += count
+    if index.stop is None:
+        if step < 0:
+            stop = -1
+        else:
+            stop = count
+    else:
+        stop = int(index.stop)
+        if stop < 0:
+            stop += count
+    if start == stop:
+        if step != 1:
+            return []
+        return inrange(start, 0, count)
+    elif ( (count == 0) or
+        ((step > 0) and ((start >= count) or (start > stop))) or
+        ((step < 0) and ((start < 0) or (start < stop))) ):
+            return []
+    else:
+        start = inrange(start, 0, count - 1)
+        if step < 0:
+            stop = inrange(stop, -1, count - 1)
+        else:
+            stop = inrange(stop, 0, count)
         return range(start, stop, step)
 
+def slice_len(s):
+    """
+    Return the number of indexes referenced by a slice. Note that
+    we do not normalize the slice indexes, since we don't have a
+    sequence length to reference them to. Also note that, because
+    of this, we have to return None if there is no stop value, or
+    if start or stop are negative.
+    """
+    
+    if s.start is None:
+        start = 0
+    else:
+        start = int(s.start)
+    if start < 0:
+        return None
+    if s.stop is None:
+        return None
+    stop = int(s.stop)
+    if stop < 0:
+        return None
+    if s.step is None:
+        step = 1
+    else:
+        step = int(s.step)
+    if step == 0:
+        raise ValueError, "Slice step cannot be zero."
+    if start == stop:
+        return 0
+    else:
+        return (stop - start) // step
+
+if sys.version < 2.4:
+    
+    class _sorted_helper(SortMixin, list): pass
+    
+    def sorted(iterable, sortfunc=None, key=None):
+        if isinstance(iterable, list):
+            result = iterable[:]
+            if sortfunc is None:
+                if key is not None:
+                    sortfunc = lambda x, y: cmp(key(x), key(y))
+            if sortfunc is None:
+                result.sort()
+            else:
+                result.sort(sortfunc)
+            return result
+        else:
+            result = _sorted_helper()
+            for item in iterable:
+                result.insert_sorted(item, sortfunc, key)
+            return list(result)
+
+else:
+    
+    from __builtin__ import sorted
+
 def strtobool(s):
     """
-    Return bool from string s interpreting s as a 'Python value string'. Return
-    None if s is not 'True' or 'False'.
+    Return bool from string s interpreting s as a 'Python value string'.
+    Return None if s is not 'True' or 'False'.
     """
     
     if s == 'True':
@@ -324,7 +454,7 @@ def module_helper(modname):
 # to exclude because we actually want them to appear
 # in our namespace as modules, not classes
 
-excludes = ['__init__', 'SigSocketServer']
+excludes = ['__init__', 'coll', 'options']
 module_dict = {}
 for pathname in __path__:
     for filename in glob.glob(os.path.join(pathname, "*.py")):
