@@ -2,7 +2,7 @@
 """
 Module abstractlist
 Sub-Package STDLIB of Package PLIB
-Copyright (C) 2008 by Peter A. Donis
+Copyright (C) 2008-2009 by Peter A. Donis
 
 Released under the GNU General Public License, Version 2
 See the LICENSE and README files for more information
@@ -69,85 +69,28 @@ class abstractlist(abstractsequence):
         def __delslice__(self, i, j):
             self.__delitem__(slice(max(0, i), max(0, j)))
     
-    # __iter__, __contains__, and the comparison operators are inherited from
-    # abstractsequence
+    # __iter__, __contains__, and the comparison and arithmetic operators are
+    # inherited from abstractsequence
     
-    def __add__(self, other):
-        if hasattr(other, '__iter__'):
-            result = self.__class__(self)
-            result.extend(other)
-            return result
-        else:
-            raise TypeError, "Cannot add a non-iterable to a sequence."
-    
-    # __radd__ is inherited from abstractsequence
-    
-    def __iadd__(self, other):
-        if hasattr(other, '__iter__'):
-            self.extend(other)
-            return self
-        else:
-            raise TypeError, "Cannot add a non-iterable to a sequence."
-    
-    def __mul__(self, other):
-        if isinstance(other, int):
-            result = self.__class__()
-            if other < 0:
-                raise ValueError, "Cannot multiply sequence by a negative number."
-            elif other > 0:
-                seq = self[:]
-                for i in range(other):
-                    result.extend(seq) # need the slice copy since we'll mutate self
-            return result
-        else:
-            raise TypeError, "Can only multiply a sequence by an integer."
-    
-    __rmul__ = __mul__
-    
-    def __imul__(self, other):
-        if isinstance(other, int):
-            if other < 0:
-                raise ValueError, "Cannot multiply sequence by a negative number."
-            elif other == 0:
-                self.clear()
-            else:
-                seq = self[:]
-                for i in range(other - 1):
-                    self.extend(seq)
-            return self
-        else:
-            raise TypeError, "Can only multiply a sequence by an integer."
-    
-    # index and count are inherited from abstractsequence
+    # index, count, and reverse are inherited from abstractsequence
     
     def append(self, value):
         self.extend((value,))
     
     def extend(self, sequence):
-        if hasattr(sequence, '__iter__'):
-            self.__setitem__(slice(self.__len__(), self.__len__()), sequence)
-        else:
-            raise TypeError, "Can only extend by an iterable."
+        self[len(self):len(self)] = sequence
     
     def insert(self, index, value):
-        self.__setitem__(slice(index, index), (value,))
+        self[index:index] = (value,)
     
     def remove(self, value):
-        self.__delitem__(self.index(value))
+        del self[self.index(value)]
     
     def pop(self, index=-1):
-        result = self.__getitem__(index)
-        self.__delitem__(index)
+        result = self[index]
+        del self[index]
         return result
     
-    def reverse(self):
-        last = self.__len__() - 1
-        for index in range((last + 1)/2):
-            dual = last - index
-            item = self.__getitem__(index)
-            self.__setitem__(index, self.__getitem__(dual))
-            self.__setitem__(dual, item)
-    
     def sort(self, cmp=None, key=str.lower, reverse=False):
         """ Sort the list items in place. """
         raise NotImplementedError
@@ -156,6 +99,12 @@ class abstractlist(abstractsequence):
     # mappings have it, not sequences
     
     def clear(self):
-        """ Remove all elements from the list. """
-        while self.__len__() > 0:
+        while len(self):
             self.pop()
+
+try:
+    from collections import MutableSequence
+except ImportError:
+    pass
+else:
+    MutableSequence.register(abstractlist)
