@@ -1,7 +1,7 @@
 #!/usr/bin/env python
 """
 TEST_STDLIB.PY -- test script for sub-package STDLIB of package PLIB
-Copyright (C) 2008 by Peter A. Donis
+Copyright (C) 2008-2009 by Peter A. Donis
 
 Released under the GNU General Public License, Version 2
 See the LICENSE and README files for more information
@@ -23,7 +23,7 @@ class CachedPropertyTest(object):
 
 class Test_cached_property(unittest.TestCase):
     
-    def runTest(self):
+    def test_all(self):
         # Initialize
         self.t = CachedPropertyTest()
         self.failUnless(not self.t.accessed)
