@@ -1,21 +1,38 @@
 #!/usr/bin/env python
 """
 Sub-Package UTILS of Package PLIB -- General Python Utilities
-Copyright (C) 2008 by Peter A. Donis
+Copyright (C) 2008-2009 by Peter A. Donis
 
 Released under the GNU General Public License, Version 2
 See the LICENSE and README files for more information
 
-This sub-package contains general utility functions.
+This sub-package contains general utility functions. It also
+contains the ModuleProxy class (which is imported to appear
+in the plib.utils namespace), which is used by several other
+PLIB sub-packages--see the PLIB.CLASSES sub-package docstring
+for details.
+
+Utility functions currently provided:
+
+recurselist, recursedict -- when you have a class field that's
+    a container, these functions provide a way of combining all
+    the values in your class's MRO, so you don't have to repeat
+    them in derived classes.
+
+locate -- generator that yields all filenames starting at a
+    root location (by default, the current directory) that match
+    a given pattern.
 """
 
 import os
 import fnmatch
 
+from ModuleProxy import ModuleProxy
+
 def _recurse(klass, name, result, methodname):
     method = getattr(result, methodname)
     for c in klass.__mro__:
-        if c.__dict__.has_key(name):
+        if name in c.__dict__:
             method(c.__dict__[name])
     return result
 
