@@ -1,15 +1,15 @@
 #!/usr/bin/env python
 """
 Sub-Package XML of Package PLIB -- Python XML and XSLT Utilities
-Copyright (C) 2008 by Peter A. Donis
+Copyright (C) 2008-2009 by Peter A. Donis
 
 Released under the GNU General Public License, Version 2
 See the LICENSE and README files for more information
 
 XML/XSLT utilities based on libxml2/libxslt,
-using the lxml Python implementation. This
+using the LXML Python implementation. This
 supports the ElementTree API, but also adds
-the following key items provided by lxml but
+the following key items provided by LXML but
 not standard etree:
 
 - Custom element classes;
