@@ -2,10 +2,21 @@
 """
 Module CLASSES -- Common XML Classes
 Sub-Package XML of Package PLIB -- Python XML and XSLT Utilities
-Copyright (C) 2008 by Peter A. Donis
+Copyright (C) 2008-2009 by Peter A. Donis
 
 Released under the GNU General Public License, Version 2
 See the LICENSE and README files for more information
+
+This module builds on the custom element class functionality
+provided by LXML to provide the following features:
+
+- Attributes of XML nodes appear as instance attributes on
+  the Python node class instance, with the data converted
+  between the strings in the XML file and the appropriate
+  Python data type (given by a class field on the custom
+  node class);
+- DTD generation is automated once the appropriate class
+  fields on each custom node class are filled in.
 """
 
 from lxml import etree
@@ -16,19 +27,19 @@ from plib.xml.defs import *
 
 # 'Attribute property' functions
 
-def _getprop(propname, filter=None):
-    if filter is not None:
+def _getprop(propname, form=None):
+    if form is not None:
         def _getfunc(self):
-            return filter(self.get(propname))
+            return form(self.get(propname))
     else:
         def _getfunc(self):
             return self.get(propname)
     return _getfunc
 
-def _setprop(propname, filter=None):
-    if filter is not None:
+def _setprop(propname, form=None):
+    if form is not None:
         def _setfunc(self, value):
-            self.set(propname, filter(value))
+            self.set(propname, form(value))
     else:
         def _setfunc(self, value):
             self.set(propname, value)
@@ -469,7 +480,8 @@ class RootMeta(TagMeta):
         which this is a root node. Return the DTD as a string.
         """
         
-        return "\n".join([cls.dtdheader(), cls.dtdstart(), cls.dtdimports(), cls.dtdentry(cls.rootname, []), cls.dtdend()])
+        return "\n".join([cls.dtdheader(), cls.dtdstart(), cls.dtdimports(),
+            cls.dtdentry(cls.rootname, []), cls.dtdend()])
 
 class RootTag(Tag):
     """
@@ -526,6 +538,8 @@ class Tree(object):
     tagdict = {}
     strip = None
     val = None
+    decl = None
+    doctype = None
     encoding = None
     indent = None
     
@@ -562,7 +576,7 @@ class Tree(object):
         Serialize XML tree to string with given encoding and indentation.
         """
         
-        return io.toString(self.tree, self.encoding, self.indent)
+        return io.toString(self.tree, self.encoding, self.indent, self.decl, self.doctype)
     
     def save_to(self, filename):
         """
