@@ -2,10 +2,13 @@
 """
 Module IO -- XML Parsing and Serialization
 Sub-Package XML of Package PLIB -- Python XML and XSLT Utilities
-Copyright (C) 2008 by Peter A. Donis
+Copyright (C) 2008-2009 by Peter A. Donis
 
 Released under the GNU General Public License, Version 2
 See the LICENSE and README files for more information
+
+This module includes classes and functions for XML parsing
+and serialization using the LXML library.
 """
 
 import sys
@@ -20,6 +23,7 @@ default_element = None
 strip_blanktext = True
 dtd_validate = False
 
+builtin_xml_decl = True
 default_encoding = "utf-8"
 indent_output = True
 
@@ -94,14 +98,14 @@ def get_parser(look=None, elem=None, strip=None, val=None):
     
     Possibilities for parameters are:
     
-    - Specify a parser object: set pxml.default_parser to the desired object.
-      The object must be an instance of etree.XMLParser or a subclass. If
-      this option is used, pxml.default_parser is returned and all other
+    - Specify a parser object: set the default_parser global to the desired
+      object. The object must be an instance of etree.XMLParser or a subclass.
+      If this option is used, the default_parser is returned and all other
       parameters are ignored.
     
-    - Specify a lookup object: set pxml.default_lookup to the desired object
-      (if you want it to apply to all parsers) or pass an object as the
-      look parameter. The object must be an instance of a subclass of
+    - Specify a lookup object: set the default_lookup global to the desired
+      object (if you want it to apply to all parsers) or pass an object as
+      the look parameter. The object must be an instance of a subclass of
       etree.CustomElementClassLookup. The parser returned will use the
       specified lookup object to define custom element classes. If this
       parameter is specified, the elem parameter will be ignored.
@@ -110,26 +114,26 @@ def get_parser(look=None, elem=None, strip=None, val=None):
       it is used to construct a TagLookup instance, and that object is then
       used as the lookup object for the parser. See the TagLookup docstring.
     
-    - Specify a default element class: set pxml.default_element to the desired
-      class or pass the class as the elem parameter. The class must be a
-      subclass of lxml.etree.ElementBase. The parser returned will use the
+    - Specify a default element class: set the default_element global to the
+      desired class or pass the class as the elem parameter. The class must be
+      a subclass of lxml.etree.ElementBase. The parser returned will use the
       specified class as its default element class. Note that this will only
       take effect if the lookup parameter is not used (see above).
-    
+      
       (NOTE: This is *not* the same as using etree.setDefaultElementClass to
-      set the default element class; pxml.default_element or the elem parameter
-      only applies to elements generated by the parsers returned by this
-      function. Elements generated by other means, such as the default Element
-      and ElementTree factories, will use the global lxml default, which can
-      be changed by calling etree.setDefaultElementClass. The parser-specific
+      set the default element class; the default_element global or the elem
+      parameter only applies to elements generated by the parsers returned by
+      this function. Elements generated by other means, such as the default
+      Element and ElementTree factories, will use the global lxml default, which
+      can be changed by calling etree.setDefaultElementClass. The parser-specific
       scheme implemented here was considered preferable because the anticipated
       use case will have multiple possible mappings of tag names to element
       classes, rather than a single global one.)
     
     - Stripping blank whitespace: the strip parameter can be passed to control
-      this, or pxml.strip_blanktext can be set to define global behavior. Note that
-      if this is turned on (which is the default), lxml will only strip blank
-      whitespace if it is certain that it isn't actual text. See the lxml
+      this, or the strip_blanktext global can be set to define global behavior.
+      Note that if this is turned on (which is the default), lxml will only strip
+      blank whitespace if it is certain that it isn't actual text. See the lxml
       documentation.
     """
     
@@ -169,22 +173,18 @@ def _parse(f, look, elem, strip, val):
     return result
 
 def parseFile(filename, look=None, elem=None, strip=None, val=None):
-    """ Return a parsed lxml tree from file filename """
+    """ Return a parsed LXML tree from file filename """
     return _parse(file(filename), look, elem, strip, val)
 
 def parseString(s, look=None, elem=None, strip=None, val=None):
-    """ Return a parsed lxml tree from string s """
+    """ Return a parsed LXML tree from string s """
     return _parse(StringIO(s), look, elem, strip, val)
 
 # Utility functions for output
 
 def _xmlheader(tree, encoding):
-    # NOTE: Why doesn't lxml do this automatically? It can output
-    # the xml declaration (by passing xml_declaration=True to the
-    # serialization function), but there doesn't seem to be any
-    # way to automatically output the doctype string, and since that
-    # goes *between* the xml declaration and the actual tree, you're
-    # SOL if you try to use xml_declaration=True with a doctype!
+    """ Utility function for use in toString below if the built-in LXML
+    support for xml declaration is not used. """
     return '<?xml version="%s" encoding="%s"?>' % (tree.docinfo.xml_version, encoding)
 
 def _writefile(f, s):
@@ -200,9 +200,14 @@ def _writefilename(filename, s):
 
 # XML file and string serialization functions
 
-def toString(tree, default=None, indent=None):
+def toString(tree, default=None, indent=None, xmldecl=None, doctype=None):
     """
-    Return lxml tree serialized as string with given encoding and indentation.
+    Return lxml tree serialized as string with given encoding and indentation. Also
+    handles the XML declaration according to the xmldecl parameter: if True, uses
+    the built-in XML support, otherwise includes it manually, and also checks the
+    doctype argument, and includes it instead of the built-in LXML doctype for the
+    tree if it is not None (this is useful if you want to do tricks with the decl
+    or doctype that LXML doesn't support).
     """
     
     if tree.docinfo.encoding is None:
@@ -217,13 +222,20 @@ def toString(tree, default=None, indent=None):
             indent = indent_output
         else:
             indent = False
-    if indent:
-        sep = "\n"
-    else:
-        sep = ""
-    return sep.join(filter(lambda x: len(x) > 0,
-        (_xmlheader(tree, enc), tree.docinfo.doctype,
-        etree.tostring(tree, encoding=enc, pretty_print=indent))))
+    if xmldecl is None:
+        xmldecl = builtin_xml_decl
+    result = etree.tostring(tree, encoding=enc, pretty_print=indent, xml_declaration=xmldecl)
+    if not xmldecl:
+        # Can't override a doctype that's already present
+        # TODO: figure out a way to strip the old doctype and insert a new one
+        if (doctype is None) or tree.docinfo.doctype:
+            doctype = ""
+        if indent:
+            sep = "\n"
+        else:
+            sep = ""
+        result = sep.join(x for x in (_xmlheader(tree, enc), doctype, result) if len(x) > 0)
+    return result
 
 def toFile(tree, f, default=None, indent=None):
     """
